@@ -19,6 +19,7 @@
 
 # discrete
 #   ratio
+#   count
 #   facetbar
 #   blank
 
@@ -46,7 +47,6 @@ fortify_SharedData <- function(model, data, ...) {
 }
 
 fix_data <- function(data) {
-
   if (inherits(data, "SharedData")) {
     data <- fortify_SharedData(data)
   }
@@ -54,7 +54,7 @@ fix_data <- function(data) {
   data <- fortify(data)
   data <- as.data.frame(data)
 
-  for (i in 1:dim(data)[2] ) {
+  for (i in 1:dim(data)[2]) {
     if (is.character(data[[i]])) {
       data[[i]] <- as.factor(data[[i]])
     }
@@ -78,19 +78,22 @@ fix_column_values <- function(
   columnLabelsName,
   isSharedData = FALSE
 ) {
-
   colnamesData <- colnames(data)
 
   if (is.character(columns)) {
-    colNumValues <- lapply(columns, function(colName){
+    colNumValues <- lapply(columns, function(colName) {
       which(colnamesData == colName)
     })
     isFound <- as.logical(unlist(lapply(colNumValues, length)))
     if (any(!isFound)) {
       stop(
-        "Columns in '", columnsName, "' not found in data: c(",
+        "Columns in '",
+        columnsName,
+        "' not found in data: c(",
         str_c(str_c("'", columns[!isFound], "'"), collapse = ", "),
-        "). Choices: c('", paste(colnamesData, collapse = "', '"), "')"
+        "). Choices: c('",
+        paste(colnamesData, collapse = "', '"),
+        "')"
       )
     }
     columns <- unlist(colNumValues)
@@ -98,31 +101,61 @@ fix_column_values <- function(
 
   if (any(columns > ncol(data))) {
     stop(
-      "Make sure your numeric '", columnsName, "'",
-      " values are less than or equal to ", ncol(data), ".\n",
-      "\t", columnsName, " = c(", str_c(columns, collapse = ", "), ")"
+      "Make sure your numeric '",
+      columnsName,
+      "'",
+      " values are less than or equal to ",
+      ncol(data),
+      ".\n",
+      "\t",
+      columnsName,
+      " = c(",
+      str_c(columns, collapse = ", "),
+      ")"
     )
   }
   if (any(columns < 1)) {
     stop(
-      "Make sure your numeric '", columnsName, "' values are positive.", "\n",
-      "\t", columnsName, " = c(", paste(columns, collapse = ", "), ")"
+      "Make sure your numeric '",
+      columnsName,
+      "' values are positive.",
+      "\n",
+      "\t",
+      columnsName,
+      " = c(",
+      paste(columns, collapse = ", "),
+      ")"
     )
   }
-  if (any( (columns %% 1) != 0)) {
+  if (any((columns %% 1) != 0)) {
     stop(
-      "Make sure your numeric '", columnsName, "' values are integers.", "\n",
-      "\t", columnsName, " = c(", paste(columns, collapse = ", "), ")"
+      "Make sure your numeric '",
+      columnsName,
+      "' values are integers.",
+      "\n",
+      "\t",
+      columnsName,
+      " = c(",
+      paste(columns, collapse = ", "),
+      ")"
     )
   }
 
   if (!is.null(columnLabels)) {
     if (length(columnLabels) != length(columns)) {
       stop(
-        "The length of the '", columnLabelsName, "'",
-        " does not match the length of the '", columnsName, "' being used.",
-        " Labels: c('", paste(columnLabels, collapse = ", "), "')\n",
-        " Columns: c('", paste(columns, collapse = ", "), "')"
+        "The length of the '",
+        columnLabelsName,
+        "'",
+        " does not match the length of the '",
+        columnsName,
+        "' being used.",
+        " Labels: c('",
+        paste(columnLabels, collapse = ", "),
+        "')\n",
+        " Columns: c('",
+        paste(columns, collapse = ", "),
+        "')"
       )
     }
   }
@@ -130,15 +163,6 @@ fix_column_values <- function(
   columns
 }
 
-warn_deprecated <- function(is_supplied, title) {
-  if (is_supplied) {
-    warning(paste(
-      "'", title, "' will be deprecated in future versions.  Please remove it from your code",
-      sep = ""
-    ))
-  }
-}
-
 stop_if_bad_mapping <- function(mapping) {
   if (is.numeric(mapping)) {
     stop(
@@ -148,18 +172,6 @@ stop_if_bad_mapping <- function(mapping) {
   }
 }
 
-warn_if_args_exist <- function(args) {
-  if (length(args) > 0) {
-    argNames <- names(args)
-    warning(str_c(
-      "Extra arguments: ",
-      str_c(shQuote(argNames), collapse = ", "), " are being ignored.",
-      "  If these are meant to be aesthetics, submit them using the",
-      " 'mapping' variable within ggpairs with ggplot2::aes or ggplot2::aes_string."
-    ))
-  }
-}
-
 fix_axis_label_choice <- function(axisLabels, axisLabelChoices) {
   if (length(axisLabels) > 1) {
     axisLabels <- axisLabels[1]
@@ -169,7 +181,9 @@ fix_axis_label_choice <- function(axisLabels, axisLabelChoices) {
     warning(str_c(
       "'axisLabels' not in c(",
       str_c(str_c("'", axisLabelChoices, "'"), collapse = ", "),
-      ").  Reverting to '", axisLabelChoices[1], "'"
+      ").  Reverting to '",
+      axisLabelChoices[1],
+      "'"
     ))
     axisLabelChoice <- 1
   }
@@ -192,9 +206,15 @@ stop_if_high_cardinality <- function(data, columns, threshold) {
       level_length <- length(levels(data_col))
       if (level_length > threshold) {
         stop(
-          "Column '", col, "' has more levels (", level_length, ")",
-          " than the threshold (", threshold, ") allowed.\n",
-          "Please remove the column or increase the 'cardinality_threshold' parameter. Increasing the cardinality_threshold may produce long processing times" # nolint
+          "Column '",
+          col,
+          "' has more levels (",
+          level_length,
+          ")",
+          " than the threshold (",
+          threshold,
+          ") allowed.\n",
+          "Please remove the column or increase the 'cardinality_threshold' parameter. Increasing the cardinality_threshold may produce long processing times"
         )
       }
     }
@@ -202,21 +222,20 @@ stop_if_high_cardinality <- function(data, columns, threshold) {
 }
 
 
-
-#' ggduo - A ggplot2 generalized pairs plot for two columns sets of a data.frame
+#' \pkg{ggplot2} generalized pairs plot for two columns sets of data
 #'
 #' Make a matrix of plots with a given data set with two different column sets
 #'
 #' @details
 #' \code{types} is a list that may contain the variables
-#' 'continuous', 'combo', 'discrete', and 'na'. Each element of the list may be a function or a string.  If a string is supplied, it must implement one of the following options:
-#'\describe{
-#'  \item{continuous}{exactly one of ('points', 'smooth', 'smooth_loess', 'density', 'cor', 'blank'). This option is used for continuous X and Y data.}
-#'  \item{comboHorizontal}{exactly one of ('box', 'box_no_facet', 'dot', 'dot_no_facet', 'facethist', 'facetdensity', 'denstrip', 'blank'). This option is used for either continuous X and categorical Y data or categorical X and continuous Y data.}
-#'  \item{comboVertical}{exactly one of ('box', 'box_no_facet', 'dot', 'dot_no_facet', 'facethist', 'facetdensity', 'denstrip', 'blank'). This option is used for either continuous X and categorical Y data or categorical X and continuous Y data.}
-#'  \item{discrete}{exactly one of ('facetbar', 'ratio', 'blank'). This option is used for categorical X and Y data.}
-#'  \item{na}{exactly one of ('na', 'blank').  This option is used when all X data is \code{NA}, all Y data is \code{NA}, or either all X or Y data is \code{NA}.}
-#'}
+#' 'continuous', 'combo', 'discrete', and 'na'. Each element of the list may be a function or a string.  If a string is supplied, If a string is supplied, it must be a character string representing the tail end of a \code{ggally_NAME} function. The list of current valid \code{ggally_NAME} functions is visible in a dedicated vignette.
+#' \describe{
+#'  \item{continuous}{This option is used for continuous X and Y data.}
+#'  \item{comboHorizontal}{This option is used for either continuous X and categorical Y data or categorical X and continuous Y data.}
+#'  \item{comboVertical}{This option is used for either continuous X and categorical Y data or categorical X and continuous Y data.}
+#'  \item{discrete}{This option is used for categorical X and Y data.}
+#'  \item{na}{This option is used when all X data is \code{NA}, all Y data is \code{NA}, or either all X or Y data is \code{NA}.}
+#' }
 #'
 #' If 'blank' is ever chosen as an option, then ggduo will produce an empty plot.
 #'
@@ -236,66 +255,88 @@ stop_if_high_cardinality <- function(data, columns, threshold) {
 #' @template ggmatrix-legend-param
 #' @param cardinality_threshold maximum number of levels allowed in a character / factor column.  Set this value to NULL to not check factor columns. Defaults to 15
 #' @template ggmatrix-progress
-#' @param legends deprecated
+#' @param legends `r lifecycle::badge('deprecated')`
+#' @param xProportions,yProportions Value to change how much area is given for each plot. Either \code{NULL} (default), numeric value matching respective length, \code{grid::\link[grid]{unit}} object with matching respective length or \code{"auto"} for automatic relative proportions based on the number of levels for categorical variables.
 #' @export
 #' @examples
-#'  # small function to display plots only if it's interactive
-#'  p_ <- GGally::print_if_interactive
+#' # small function to display plots only if it's interactive
+#' p_ <- GGally::print_if_interactive
 #'
-#'  data(baseball, package = "plyr")
+#' data(baseball)
 #'
-#'  # Keep players from 1990-1995 with at least one at bat
-#'  # Add how many singles a player hit
-#'  # (must do in two steps as X1b is used in calculations)
-#'  dt <- transform(
-#'    subset(baseball, year >= 1990 & year <= 1995 & ab > 0),
-#'    X1b = h - X2b - X3b - hr
-#'  )
-#'  # Add
-#'  #  the player's batting average,
-#'  #  the player's slugging percentage,
-#'  #  and the player's on base percentage
-#'  # Make factor a year, as each season is discrete
-#'  dt <- transform(
-#'    dt,
-#'    batting_avg = h / ab,
-#'    slug = (X1b + 2*X2b + 3*X3b + 4*hr) / ab,
-#'    on_base = (h + bb + hbp) / (ab + bb + hbp),
-#'    year = as.factor(year)
-#'  )
+#' # Keep players from 1990-1995 with at least one at bat
+#' # Add how many singles a player hit
+#' # (must do in two steps as X1b is used in calculations)
+#' dt <- transform(
+#'   subset(baseball, year >= 1990 & year <= 1995 & ab > 0),
+#'   X1b = h - X2b - X3b - hr
+#' )
+#' # Add
+#' #  the player's batting average,
+#' #  the player's slugging percentage,
+#' #  and the player's on base percentage
+#' # Make factor a year, as each season is discrete
+#' dt <- transform(
+#'   dt,
+#'   batting_avg = h / ab,
+#'   slug = (X1b + 2 * X2b + 3 * X3b + 4 * hr) / ab,
+#'   on_base = (h + bb + hbp) / (ab + bb + hbp),
+#'   year = as.factor(year)
+#' )
 #'
 #'
-#'  pm <- ggduo(
-#'    dt,
-#'    c("year", "g", "ab", "lg"),
-#'    c("batting_avg", "slug", "on_base"),
-#'    mapping = ggplot2::aes(color = lg)
-#'  )
-#'  # Prints, but
-#'  #   there is severe over plotting in the continuous plots
-#'  #   the labels could be better
-#'  #   want to add more hitting information
-#'  p_(pm)
+#' pm <- ggduo(
+#'   dt,
+#'   c("year", "g", "ab", "lg"),
+#'   c("batting_avg", "slug", "on_base"),
+#'   mapping = ggplot2::aes(color = lg)
+#' )
+#' # Prints, but
+#' #   there is severe over plotting in the continuous plots
+#' #   the labels could be better
+#' #   want to add more hitting information
+#' p_(pm)
 #'
-#'  # address overplotting issues and add a title
-#'  pm <- ggduo(
-#'    dt,
-#'    c("year", "g", "ab", "lg"),
-#'    c("batting_avg", "slug", "on_base"),
-#'    columnLabelsX = c("year", "player game count", "player at bat count", "league"),
-#'    columnLabelsY = c("batting avg", "slug %", "on base %"),
-#'    title = "Baseball Hitting Stats from 1990-1995",
-#'    mapping = ggplot2::aes(color = lg),
-#'    types = list(
-#'      # change the shape and add some transparency to the points
-#'      continuous = wrap("smooth_loess", alpha = 0.50, shape = "+")
-#'    ),
-#'    showStrips = FALSE
-#'  );
+#' # address overplotting issues and add a title
+#' pm <- ggduo(
+#'   dt,
+#'   c("year", "g", "ab", "lg"),
+#'   c("batting_avg", "slug", "on_base"),
+#'   columnLabelsX = c("year", "player game count", "player at bat count", "league"),
+#'   columnLabelsY = c("batting avg", "slug %", "on base %"),
+#'   title = "Baseball Hitting Stats from 1990-1995",
+#'   mapping = ggplot2::aes(color = lg),
+#'   types = list(
+#'     # change the shape and add some transparency to the points
+#'     continuous = wrap("smooth_loess", alpha = 0.50, shape = "+")
+#'   ),
+#'   showStrips = FALSE
+#' )
 #'
-#'  p_(pm)
+#' p_(pm)
 #'
+#' # Use "auto" to adapt width of the sub-plots
+#' pm <- ggduo(
+#'   dt,
+#'   c("year", "g", "ab", "lg"),
+#'   c("batting_avg", "slug", "on_base"),
+#'   mapping = ggplot2::aes(color = lg),
+#'   xProportions = "auto"
+#' )
 #'
+#' p_(pm)
+#'
+#' # Custom widths & heights of the sub-plots
+#' pm <- ggduo(
+#'   dt,
+#'   c("year", "g", "ab", "lg"),
+#'   c("batting_avg", "slug", "on_base"),
+#'   mapping = ggplot2::aes(color = lg),
+#'   xProportions = c(6, 4, 3, 2),
+#'   yProportions = c(1, 2, 1)
+#' )
+#'
+#' p_(pm)
 #'
 #' # Example derived from:
 #' ## R Data Analysis Examples | Canonical Correlation Analysis.  UCLA: Institute for Digital
@@ -351,7 +392,7 @@ stop_if_high_cardinality <- function(data, columns, threshold) {
 #'   rev(psych_variables), academic_variables,
 #'   types = list(continuous = loess_with_cor),
 #'   showStrips = FALSE,
-#'   legend = c(5,2)
+#'   legend = c(5, 2)
 #' )
 #' suppressWarnings(p_(pm))
 #'
@@ -363,60 +404,52 @@ stop_if_high_cardinality <- function(data, columns, threshold) {
 #'   rev(psych_variables), academic_variables,
 #'   types = list(continuous = loess_with_cor),
 #'   showStrips = FALSE,
-#'   legend = c(5,2)
+#'   legend = c(5, 2)
 #' ) +
 #'   ggplot2::theme(legend.position = "bottom")
 #' suppressWarnings(p_(pm))
-#
-#
-#
 # pm <- ggduo(
-#   dt,
-#   c("year", "g", "ab", "lg", "lg"),
-#   c("batting_avg", "slug", "on_base", "hit_type"),
-#   columnLabelsX = c("year", "player game count", "player at bat count", "league", ""),
-#   columnLabelsY = c("batting avg", "slug %", "on base %", "hit type"),
-#   title = "Baseball Hitting Stats from 1990-1995 (player strike in 1994)",
-#   mapping = aes(color = year),
-#   types = list(
-#     continuous = wrap("smooth_loess", alpha = 0.50, shape = "+"),
-#     comboHorizontal = wrap(display_hit_type_combo, binwidth = 15),
-#     discrete = wrap(display_hit_type_discrete, color = "black", size = 0.15)
-#   ),
-#   showStrips = FALSE
+#' #  dt,
+#' #  c("year", "g", "ab", "lg", "lg"),
+#' #  c("batting_avg", "slug", "on_base", "hit_type"),
+#' #  columnLabelsX = c("year", "player game count", "player at bat count", "league", ""),
+#' #  columnLabelsY = c("batting avg", "slug %", "on base %", "hit type"),
+#' #  title = "Baseball Hitting Stats from 1990-1995 (player strike in 1994)",
+#' #  mapping = aes(color = year),
+#' #  types = list(
+#' #    continuous = wrap("smooth_loess", alpha = 0.50, shape = "+"),
+#' #    comboHorizontal = wrap(display_hit_type_combo, binwidth = 15),
+#' #    discrete = wrap(display_hit_type_discrete, color = "black", size = 0.15)
+#' #  ),
+#' #  showStrips = FALSE
 # );
-#
-# # make the 5th column blank, except for the legend
-# pm[1,5] <- NULL
-# pm[2,5] <- grab_legend(pm[2,1])
-# pm[3,5] <- NULL
-# pm[4,5] <- NULL
-#
+#' ## make the 5th column blank, except for the legend
+# pm[1, 5] <- NULL
+# pm[2, 5] <- grab_legend(pm[2, 1])
+# pm[3, 5] <- NULL
+# pm[4, 5] <- NULL
 # pm
-#
 # ggduo(
-#   australia_PISA2012,
-#   c("gender", "age", "homework", "possessions"),
-#   c("PV1MATH", "PV2MATH", "PV3MATH", "PV4MATH", "PV5MATH"),
-#   types = list(
-#     continuous = "points",
-#     combo = "box",
-#     discrete = "ratio"
-#   )
+#' #  australia_PISA2012,
+#' #  c("gender", "age", "homework", "possessions"),
+#' #  c("PV1MATH", "PV2MATH", "PV3MATH", "PV4MATH", "PV5MATH"),
+#' #  types = list(
+#' #    continuous = "points",
+#' #    combo = "box",
+#' #    discrete = "ratio"
+#' #  )
 # )
-#
 # ggduo(
-#   australia_PISA2012,
-#   c("gender", "age", "homework", "possessions"),
-#   c("PV1MATH", "PV2MATH", "PV3MATH", "PV4MATH", "PV5MATH"),
-#   mapping = ggplot2::aes(color = gender),
-#   types = list(
-#     continuous = wrap("smooth", alpha = 0.25, method = "loess"),
-#     combo = "box",
-#     discrete = "ratio"
-#   )
+#' #  australia_PISA2012,
+#' #  c("gender", "age", "homework", "possessions"),
+#' #  c("PV1MATH", "PV2MATH", "PV3MATH", "PV4MATH", "PV5MATH"),
+#' #  mapping = ggplot2::aes(color = gender),
+#' #  types = list(
+#' #    continuous = wrap("smooth", alpha = 0.25, method = "loess"),
+#' #    combo = "box",
+#' #    discrete = "ratio"
+#' #  )
 # )
-#
 # ggduo(australia_PISA2012, c("gender", "age", "homework", "possessions"), c("PV1MATH", "PV1READ", "PV1SCIE"), types = list(continuous = "points", combo = "box", discrete = "ratio"))
 # ggduo(australia_PISA2012, c("gender", "age", "homework", "possessions"), c("PV1MATH", "PV1READ", "PV1SCIE"), types = list(continuous = wrap("smooth", alpha = 0.25, method = "loess"), combo = "box", discrete = "ratio"), mapping = ggplot2::aes(color = gender))
 ggduo <- function(
@@ -429,7 +462,7 @@ ggduo <- function(
     continuous = "smooth_loess",
     comboVertical = "box_no_facet",
     comboHorizontal = "facethist",
-    discrete = "ratio"
+    discrete = "count"
   ),
   axisLabels = c("show", "none"),
   columnLabelsX = colnames(data[columnsX]),
@@ -442,10 +475,17 @@ ggduo <- function(
   legend = NULL,
   cardinality_threshold = 15,
   progress = NULL,
-  legends = stop("deprecated")
+  xProportions = NULL,
+  yProportions = NULL,
+  legends = deprecated()
 ) {
-
-  warn_deprecated(!missing(legends), "legends")
+  if (lifecycle::is_present(legends)) {
+    lifecycle::deprecate_warn(
+      when = "2.3.0",
+      what = "ggduo(legends)",
+      details = "Ability to put legends in each plot will be dropped in next releases."
+    )
+  }
 
   isSharedData <- inherits(data, "SharedData")
   data_ <- fix_data(data)
@@ -453,8 +493,10 @@ ggduo <- function(
 
   # fix args
   if (
-    !missing(mapping) & !is.list(mapping) &
-    !missing(columnsX) & missing(columnsY)
+    !missing(mapping) &&
+      !is.list(mapping) &&
+      !missing(columnsX) &&
+      missing(columnsY)
   ) {
     columnsY <- columnsX
     columnsX <- mapping
@@ -463,15 +505,33 @@ ggduo <- function(
 
   stop_if_bad_mapping(mapping)
 
-  columnsX <- fix_column_values(data, columnsX, columnLabelsX, "columnsX", "columnLabelsX")
-  columnsY <- fix_column_values(data, columnsY, columnLabelsY, "columnsY", "columnLabelsY")
+  columnsX <- fix_column_values(
+    data,
+    columnsX,
+    columnLabelsX,
+    "columnsX",
+    "columnLabelsX"
+  )
+  columnsY <- fix_column_values(
+    data,
+    columnsY,
+    columnLabelsY,
+    "columnsY",
+    "columnLabelsY"
+  )
 
   stop_if_high_cardinality(data, columnsX, cardinality_threshold)
   stop_if_high_cardinality(data, columnsY, cardinality_threshold)
 
+  xProportions <- ggmatrix_proportions(xProportions, data, columnsX)
+  yProportions <- ggmatrix_proportions(yProportions, data, columnsY)
+
   types <- check_and_set_ggpairs_defaults(
-    "types", types,
-    continuous = "smooth_loess", discrete = "ratio", na = "na",
+    "types",
+    types,
+    continuous = "smooth_loess",
+    discrete = "count",
+    na = "na",
     isDuo = TRUE
   )
 
@@ -498,7 +558,6 @@ ggduo <- function(
   dataTypes <- plot_types(data, columnsX, columnsY, allowDiag = FALSE)
 
   ggduoPlots <- lapply(seq_len(nrow(dataTypes)), function(i) {
-
     plotType <- dataTypes[i, "plotType"]
 
     # posX <- dataTypes[i, "posX"]
@@ -508,7 +567,7 @@ ggduo <- function(
 
     sectionAes <- add_and_overwrite_aes(
       add_and_overwrite_aes(
-        aes_(x = as.name(xColName), y = as.name(yColName)),
+        aes(x = !!as.name(xColName), y = !!as.name(yColName)),
         mapping
       ),
       types$mapping
@@ -530,7 +589,6 @@ ggduo <- function(
     return(plotObj)
   })
 
-
   plotMatrix <- ggmatrix(
     plots = ggduoPlots,
     byrow = TRUE,
@@ -549,7 +607,9 @@ ggduo <- function(
     data = data_,
     gg = NULL,
     progress = progress,
-    legend = legend
+    legend = legend,
+    xProportions = xProportions,
+    yProportions = yProportions
   )
 
   plotMatrix
@@ -561,7 +621,7 @@ ggduo <- function(
 # make_small_strip <- function(plot_matrix, from_top, from_left, new_size = 7){
 #   up <- from_left > from_top
 #   p <- getPlot(plot_matrix, from_top, from_left)
-#   if(up)
+#   if (up)
 #     p <- p + opts(strip.text.x = element_text(size = new_size))
 #   else
 #     p <- p + opts(strip.text.y = element_text(angle = -90, size = new_size))
@@ -573,26 +633,26 @@ ggduo <- function(
 # small_label_diamond <- make_small_strip(small_label_diamond, 2, 2)
 # #small_label_diamond # now with much smaller strip text
 
-#' ggpairs - A ggplot2 generalized pairs plot
+#' ggplot2 generalized pairs plot
 #'
 #' Make a matrix of plots with a given data set
 #'
 #' @details
 #' \code{upper} and \code{lower} are lists that may contain the variables
-#' 'continuous', 'combo', 'discrete', and 'na'. Each element of the list may be a function or a string.  If a string is supplied, it must implement one of the following options:
-#'\describe{
-#'  \item{continuous}{exactly one of ('points', 'smooth', 'smooth_loess', 'density', 'cor', 'blank'). This option is used for continuous X and Y data.}
-#'  \item{combo}{exactly one of ('box', 'box_no_facet', 'dot', 'dot_no_facet', 'facethist', 'facetdensity', 'denstrip', 'blank'). This option is used for either continuous X and categorical Y data or categorical X and continuous Y data.}
-#'  \item{discrete}{exactly one of ('facetbar', 'ratio', 'blank'). This option is used for categorical X and Y data.}
-#'  \item{na}{exactly one of ('na', 'blank').  This option is used when all X data is \code{NA}, all Y data is \code{NA}, or either all X or Y data is \code{NA}.}
-#'}
+#' 'continuous', 'combo', 'discrete', and 'na'. Each element of the list may be a function or a string.  If a string is supplied, it must be a character string representing the tail end of a \code{ggally_NAME} function. The list of current valid \code{ggally_NAME} functions is visible in a dedicated vignette.
+#' \describe{
+#'  \item{continuous}{This option is used for continuous X and Y data.}
+#'  \item{combo}{This option is used for either continuous X and categorical Y data or categorical X and continuous Y data.}
+#'  \item{discrete}{This option is used for categorical X and Y data.}
+#'  \item{na}{This option is used when all X data is \code{NA}, all Y data is \code{NA}, or either all X or Y data is \code{NA}.}
+#' }
 #'
 #' \code{diag} is a list that may only contain the variables 'continuous', 'discrete', and 'na'. Each element of the diag list is a string implementing the following options:
-#'\describe{
+#' \describe{
 #'  \item{continuous}{exactly one of ('densityDiag', 'barDiag', 'blankDiag'). This option is used for continuous X data.}
 #'  \item{discrete}{exactly one of ('barDiag', 'blankDiag'). This option is used for categorical X and Y data.}
 #'  \item{na}{exactly one of ('naDiag', 'blankDiag').  This option is used when all X data is \code{NA}.}
-#'}
+#' }
 #'
 #' If 'blank' is ever chosen as an option, then ggpairs will produce an empty plot.
 #'
@@ -607,36 +667,37 @@ ggduo <- function(
 #' @param upper see Details
 #' @param lower see Details
 #' @param diag see Details
-#' @param params deprecated.  Please see \code{\link{wrap_fn_with_param_arg}}
-#' @param ... deprecated. Please use \code{mapping}
+#' @param params `r lifecycle::badge("deprecated")` see \code{\link{wrap_fn_with_param_arg}}
+#' @param ... `r lifecycle::badge("deprecated")` use \code{mapping}
 #' @param axisLabels either "show" to display axisLabels, "internal" for labels in the diagonal plots, or "none" for no axis labels
 #' @param columnLabels label names to be displayed.  Defaults to names of columns being used.
+#' @param proportions Value to change how much area is given for each plot. Either \code{NULL} (default), numeric value matching respective length, \code{grid::\link[grid]{unit}} object with matching respective length or \code{"auto"} for automatic relative proportions based on the number of levels for categorical variables.
 #' @template ggmatrix-labeller-param
 #' @template ggmatrix-switch-param
 #' @param showStrips boolean to determine if each plot's strips should be displayed. \code{NULL} will default to the top and right side plots only. \code{TRUE} or \code{FALSE} will turn all strips on or off respectively.
 #' @template ggmatrix-legend-param
 #' @param cardinality_threshold maximum number of levels allowed in a character / factor column.  Set this value to NULL to not check factor columns. Defaults to 15
 #' @template ggmatrix-progress
-#' @param legends deprecated
+#' @param legends `r lifecycle::badge("deprecated")`
 #' @keywords hplot
 #' @import ggplot2
 #' @references John W Emerson, Walton A Green, Barret Schloerke, Jason Crowley, Dianne Cook, Heike Hofmann, Hadley Wickham. The Generalized Pairs Plot. Journal of Computational and Graphical Statistics, vol. 22, no. 1, pp. 79-91, 2012.
-#' @author Barret Schloerke \email{schloerke@@gmail.com}, Jason Crowley \email{crowley.jason.s@@gmail.com}, Di Cook \email{dicook@@iastate.edu}, Heike Hofmann \email{hofmann@@iastate.edu}, Hadley Wickham \email{h.wickham@@gmail.com}
-#' @return ggmatrix object that if called, will print
+#' @author Barret Schloerke, Jason Crowley, Di Cook, Heike Hofmann, Hadley Wickham
+#' @return \code{\link{ggmatrix}} object that if called, will print
 #' @examples
-#'  # small function to display plots only if it's interactive
-#'  p_ <- GGally::print_if_interactive
+#' # small function to display plots only if it's interactive
+#' p_ <- GGally::print_if_interactive
 #'
 #'
 #' ## Quick example, with and without colour
 #' data(flea)
 #' ggpairs(flea, columns = 2:4)
-#' pm <- ggpairs(flea, columns = 2:4, ggplot2::aes(colour=species))
+#' pm <- ggpairs(flea, columns = 2:4, ggplot2::aes(colour = species))
 #' p_(pm)
 #' # Note: colour should be categorical, else you will need to reset
 #' # the upper triangle to use points instead of trying to compute corr
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' pm <- ggpairs(tips[, 1:3])
 #' p_(pm)
 #' pm <- ggpairs(tips, 1:3, columnLabels = c("Total Bill", "Tip", "Sex"))
@@ -661,25 +722,25 @@ ggduo <- function(
 #' p_(pm)
 #'
 #' # Use sample of the diamonds data
-#' data(diamonds, package="ggplot2")
+#' data(diamonds, package = "ggplot2")
 #' diamonds.samp <- diamonds[sample(1:dim(diamonds)[1], 1000), ]
 #'
 #' # Different aesthetics for different plot sections and plot types
 #' pm <- ggpairs(
-#'  diamonds.samp[, 1:5],
-#'  mapping = ggplot2::aes(color = cut),
-#'  upper = list(continuous = wrap("density", alpha = 0.5), combo = "box_no_facet"),
-#'  lower = list(continuous = wrap("points", alpha = 0.3), combo = wrap("dot_no_facet", alpha = 0.4)),
-#'  title = "Diamonds"
+#'   diamonds.samp[, 1:5],
+#'   mapping = ggplot2::aes(color = cut),
+#'   upper = list(continuous = wrap("density", alpha = 0.5), combo = "box_no_facet"),
+#'   lower = list(continuous = wrap("points", alpha = 0.3), combo = wrap("dot_no_facet", alpha = 0.4)),
+#'   title = "Diamonds"
 #' )
 #' p_(pm)
 #'
 #' ## Axis Label Variations
 #' # Only Variable Labels on the diagonal (no axis labels)
-#' pm <- ggpairs(tips[, 1:3], axisLabels="internal")
+#' pm <- ggpairs(tips[, 1:3], axisLabels = "internal")
 #' p_(pm)
 #' # Only Variable Labels on the outside (no axis labels)
-#' pm <- ggpairs(tips[, 1:3], axisLabels="none")
+#' pm <- ggpairs(tips[, 1:3], axisLabels = "none")
 #' p_(pm)
 #'
 #' ## Facet Label Variations
@@ -703,10 +764,10 @@ ggduo <- function(
 #' ## Plot Insertion Example
 #' custom_car <- ggpairs(mtcars[, c("mpg", "wt", "cyl")], upper = "blank", title = "Custom Example")
 #' # ggplot example taken from example(geom_text)
-#'   plot <- ggplot2::ggplot(mtcars, ggplot2::aes(x=wt, y=mpg, label=rownames(mtcars)))
-#'   plot <- plot +
-#'     ggplot2::geom_text(ggplot2::aes(colour=factor(cyl)), size = 3) +
-#'     ggplot2::scale_colour_discrete(l=40)
+#' plot <- ggplot2::ggplot(mtcars, ggplot2::aes(x = wt, y = mpg, label = rownames(mtcars)))
+#' plot <- plot +
+#'   ggplot2::geom_text(ggplot2::aes(colour = factor(cyl)), size = 3) +
+#'   ggplot2::scale_colour_discrete(l = 40)
 #' custom_car[1, 2] <- plot
 #' personal_plot <- ggally_text(
 #'   "ggpairs allows you\nto put in your\nown plot.\nLike that one.\n <---"
@@ -727,19 +788,41 @@ ggduo <- function(
 #'
 #' ## Remove panel grid lines from correlation plots
 #' pm <- ggpairs(
-#'   flea, columns = 2:4,
+#'   flea,
+#'   columns = 2:4,
 #'   upper = list(continuous = wrap(ggally_cor, displayGrid = FALSE))
 #' )
 #' p_(pm)
+#'
+#' ## Custom with/height of subplots
+#' pm <- ggpairs(tips, columns = c(2, 3, 5))
+#' p_(pm)
+#'
+#' pm <- ggpairs(tips, columns = c(2, 3, 5), proportions = "auto")
+#' p_(pm)
+#'
+#' pm <- ggpairs(tips, columns = c(2, 3, 5), proportions = c(1, 3, 2))
+#' p_(pm)
+#'
 ggpairs <- function(
   data,
   mapping = NULL,
   columns = 1:ncol(data),
   title = NULL,
-  upper = list(continuous = "cor", combo = "box_no_facet", discrete = "facetbar", na = "na"),
-  lower = list(continuous = "points", combo = "facethist", discrete = "facetbar", na = "na"),
+  upper = list(
+    continuous = "cor",
+    combo = "box_no_facet",
+    discrete = "count",
+    na = "na"
+  ),
+  lower = list(
+    continuous = "points",
+    combo = "facethist",
+    discrete = "facetbar",
+    na = "na"
+  ),
   diag = list(continuous = "densityDiag", discrete = "barDiag", na = "naDiag"),
-  params = NULL,
+  params = deprecated(),
   ...,
   xlab = NULL,
   ylab = NULL,
@@ -751,47 +834,79 @@ ggpairs <- function(
   legend = NULL,
   cardinality_threshold = 15,
   progress = NULL,
-  legends = stop("deprecated")
-){
-
-  warn_deprecated(!missing(legends), "legends")
-  warn_if_args_exist(list(...))
-  stop_if_params_exist(params)
+  proportions = NULL,
+  legends = deprecated()
+) {
+  if (lifecycle::is_present(legends)) {
+    lifecycle::deprecate_warn(
+      when = "2.3.0",
+      what = "ggpairs(legends)",
+      details = "Ability to put legends in each plot will be dropped in next releases."
+    )
+  }
+  if (lifecycle::is_present(params)) {
+    lifecycle::deprecate_warn(
+      when = "2.3.0",
+      what = "ggpairs(params)"
+    )
+  }
+  has_dots <- rlang::check_dots_empty(error = function(cnd) {
+    TRUE
+  })
+  if (isTRUE(has_dots)) {
+    lifecycle::deprecate_soft(when = "2.3.0", what = "ggpais(...)")
+  }
 
   isSharedData <- inherits(data, "SharedData")
 
   data_ <- fix_data(data)
   data <- fix_data_slim(data_, isSharedData)
 
-  if (
-    !missing(mapping) & !is.list(mapping) &
-    missing(columns)
-  ) {
-      columns <- mapping
-      mapping <- NULL
+  if (!missing(mapping) && !is.list(mapping) && missing(columns)) {
+    columns <- mapping
+    mapping <- NULL
   }
   stop_if_bad_mapping(mapping)
 
-  columns <- fix_column_values(data, columns, columnLabels, "columns", "columnLabels")
+  columns <- fix_column_values(
+    data,
+    columns,
+    columnLabels,
+    "columns",
+    "columnLabels"
+  )
 
   stop_if_high_cardinality(data, columns, cardinality_threshold)
 
   upper <- check_and_set_ggpairs_defaults(
-    "upper", upper,
-    continuous = "cor", combo = "box_no_facet", discrete = "facetbar", na = "na"
+    "upper",
+    upper,
+    continuous = "cor",
+    combo = "box_no_facet",
+    discrete = "count",
+    na = "na"
   )
   lower <- check_and_set_ggpairs_defaults(
-    "lower", lower,
-    continuous = "points", combo = "facethist", discrete = "facetbar", na = "na"
+    "lower",
+    lower,
+    continuous = "points",
+    combo = "facethist",
+    discrete = "facetbar",
+    na = "na"
   )
   diag <- check_and_set_ggpairs_defaults(
-    "diag", diag,
-    continuous = "densityDiag", discrete = "barDiag", na = "naDiag",
+    "diag",
+    diag,
+    continuous = "densityDiag",
+    discrete = "barDiag",
+    na = "naDiag",
     isDiag = TRUE
   )
 
   axisLabels <- fix_axis_label_choice(axisLabels, c("show", "internal", "none"))
 
+  proportions <- ggmatrix_proportions(proportions, data, columns)
+
   # get plot type information
   dataTypes <- plot_types(data, columns, columns, allowDiag = TRUE)
 
@@ -801,7 +916,6 @@ ggpairs <- function(
   }
 
   ggpairsPlots <- lapply(seq_len(nrow(dataTypes)), function(i) {
-
     plotType <- dataTypes[i, "plotType"]
 
     posX <- dataTypes[i, "posX"]
@@ -819,7 +933,7 @@ ggpairs <- function(
 
     sectionAes <- add_and_overwrite_aes(
       add_and_overwrite_aes(
-        aes_(x = as.name(xColName), y = as.name(yColName)),
+        aes(x = !!as.name(xColName), y = !!as.name(yColName)),
         mapping
       ),
       types$mapping
@@ -855,7 +969,9 @@ ggpairs <- function(
     data = data_,
     gg = NULL,
     progress = progress,
-    legend = legend
+    legend = legend,
+    xProportions = proportions,
+    yProportions = proportions
   )
 
   plotMatrix
@@ -867,17 +983,18 @@ ggpairs <- function(
 #' Add new aesthetics to a previous aes.
 #'
 #' @keywords internal
-#' @author Barret Schloerke \email{schloerke@@gmail.com}
+#' @author Barret Schloerke
 #' @return aes_ output
 #' @import ggplot2
 #' @rdname add_and_overwrite_aes
 #' @examples
-#' data(diamonds, package="ggplot2")
+#' data(diamonds, package = "ggplot2")
 #' diamonds.samp <- diamonds[sample(1:dim(diamonds)[1], 1000), ]
-#' pm <- ggpairs(diamonds.samp, columns = 5:7,
+#' pm <- ggpairs(diamonds.samp,
+#'   columns = 5:7,
 #'   mapping = ggplot2::aes(color = color),
-#'   upper = list(continuous = "cor", mapping = ggplot2::aes_string(color = "clarity")),
-#'   lower = list(continuous = "cor", mapping = ggplot2::aes_string(color = "cut")),
+#'   upper = list(continuous = "cor", mapping = ggplot2::aes(color = clarity)),
+#'   lower = list(continuous = "cor", mapping = ggplot2::aes(color = cut)),
 #'   title = "Diamonds Sample"
 #' )
 #' str(pm)
@@ -899,14 +1016,11 @@ add_and_overwrite_aes <- function(current, new) {
 }
 
 
-
-
-#' Aesthetic Mapping Color Fill
+#' Aesthetic mapping color fill
 #'
 #' Replace the fill with the color and make color NULL.
 #'
 #' @param current the current aesthetics
-#' @keywords internal
 #' @export
 mapping_color_to_fill <- function(current) {
   if (is.null(current)) {
@@ -925,9 +1039,9 @@ mapping_color_to_fill <- function(current) {
     current$colour <- NULL
   }
 
-  # if(!is.null(mapping$colour) && !is.null(mapping$fill)) {
+  # if (!is.null(mapping$colour) && !is.null(mapping$fill)) {
   #   # do nothing
-  # } else if(!is.null(mapping$colour)) {
+  # } else if (!is.null(mapping$colour)) {
   # }
   current
 }
@@ -961,7 +1075,8 @@ set_to_blank_list_if_blank <- function(
 }
 
 check_and_set_ggpairs_defaults <- function(
-  name, obj,
+  name,
+  obj,
   continuous = NULL,
   combo = NULL,
   discrete = NULL,
@@ -969,12 +1084,11 @@ check_and_set_ggpairs_defaults <- function(
   isDiag = FALSE,
   isDuo = FALSE
 ) {
-
   blankVal <- ifelse(isDiag, "blankDiag", "blank")
 
   obj <- set_to_blank_list_if_blank(
     obj,
-    combo = ! isDiag & ! isDuo,
+    combo = !isDiag && !isDuo,
     blank = blankVal,
     isDuo = isDuo
   )
@@ -997,9 +1111,11 @@ check_and_set_ggpairs_defaults <- function(
     obj$na <- na
   }
 
-  if (! is.null(obj$aes_string)) {
+  if (!is.null(obj$aes_string)) {
     stop(
-      "'aes_string' is a deprecated element for the section ", name, ".\n",
+      "'aes_string' is a deprecated element for the section ",
+      name,
+      ".\n",
       "Please use 'mapping' instead. "
     )
   }
@@ -1008,10 +1124,16 @@ check_and_set_ggpairs_defaults <- function(
     for (key in c("continuous", "discrete", "na")) {
       val <- obj[[key]]
       if (is.character(val)) {
-        if (! str_detect(val, "Diag$")) {
+        if (!str_detect(val, "Diag$")) {
           newVal <- paste(val, "Diag", sep = "")
           warning(paste(
-            "Changing diag$", key, " from '", val, "' to '", newVal, "'",
+            "Changing diag$",
+            key,
+            " from '",
+            val,
+            "' to '",
+            newVal,
+            "'",
             sep = ""
           ))
           obj[[key]] <- newVal
@@ -1035,18 +1157,70 @@ get_subtype_name <- function(.subType) {
 
 
 stop_if_params_exist <- function(params) {
-  if (! is.null(params)) {
-      stop(
-        "'params' is a deprecated argument.  ",
-        "Please 'wrap' the function to supply arguments. ",
-        "help(\"wrap\", package = \"GGally\")"
-      )
+  if (!is.null(params)) {
+    stop(
+      "'params' is a deprecated argument.  ",
+      "Please 'wrap' the function to supply arguments. ",
+      "help(\"wrap\", package = \"GGally\")"
+    )
   }
 }
 
 
+ggmatrix_proportions <- function(proportions, data, columns) {
+  if (is.null(proportions)) {
+    return(proportions)
+  }
 
-#diamondMatrix <- ggpairs(
+  # relative proportions if "auto"
+  # wrap in isTRUE for safe guarding
+  if (isTRUE(length(proportions) == 1 && proportions == "auto")) {
+    proportions <- c()
+    for (v in columns) {
+      if (is.numeric(data[[v]])) {
+        proportions <- c(proportions, NA)
+      } else {
+        proportions <- c(proportions, length(levels(as.factor(data[[v]]))))
+      }
+    }
+    # for numeric variables, the average
+    proportions[is.na(proportions)] <- mean(proportions, na.rm = TRUE)
+    proportions[is.na(proportions)] <- 1 # in case all are numeric
+  } else {
+    is_valid_type <- vapply(
+      proportions,
+      function(x) {
+        (!is.na(x)) &&
+          (grid::is.unit(x) || is.numeric(x))
+      },
+      logical(1)
+    )
+    if (!all(is_valid_type)) {
+      stop(
+        "proportions need to be non-NA numeric values or 'auto'. proportions: ",
+        dput_val(proportions)
+      )
+    }
+  }
+
+  if (length(proportions) == 1 && length(columns) > 1) {
+    proportions <- replicate(length(columns), proportions)
+  }
+
+  proportions
+}
+
+dput_val <- function(x) {
+  f <- file()
+  on.exit({
+    close(f)
+  })
+  dput(x, f)
+  ret <- paste0(readLines(f), collapse = "\n")
+  ret
+}
+
+# diamondMatrix <- ggpairs(
 #  diamonds,
 #  columns = 8:10,
 #  upper = list(points = "scatterplot", aes_string = aes_string(color = "cut")),
@@ -1054,13 +1228,13 @@ stop_if_params_exist <- function(params) {
 #  diag = "blank",
 ##  color = "color",
 #  title = "Diamonds"
-#)
-#if(TRUE)
-#{
+# )
+# if(TRUE)
+# {
 #
-#d <- diamonds[runif(floor(nrow(diamonds)/10), 0, nrow(diamonds)), ]
+# d <- diamonds[runif(floor(nrow(diamonds)/10), 0, nrow(diamonds)), ]
 #
-#diamondMatrix <- ggpairs(
+# diamondMatrix <- ggpairs(
 #  d,
 #  columns = 8:10,
 #  upper = list(continuous = "points", aes_string = aes_string(color = "clarity")),
@@ -1068,14 +1242,14 @@ stop_if_params_exist <- function(params) {
 #  diag = "blank",
 ##  color = "color",
 #  title = "Diamonds"
-#)
+# )
 #
 #
-#m <- mtcars
-##m$vs <- as.factor(m$vs)
-##m$cyl <- as.factor(m$cyl)
-##m$qsec <- as.factor(m$qsec)
-#carsMatrix <- ggpairs(
+# m <- mtcars
+## m$vs <- as.factor(m$vs)
+## m$cyl <- as.factor(m$cyl)
+## m$qsec <- as.factor(m$qsec)
+# carsMatrix <- ggpairs(
 #  mtcars,
 #  columns = c(1, 3, 4),
 #  upper = list(continuous = "points", aes_string = aes_string(shape = "cyl", size = 5)),
@@ -1083,7 +1257,7 @@ stop_if_params_exist <- function(params) {
 #  diag = "blank",
 #  color = "cyl",
 #  title = "mtcars",
-#)
+# )
 #
 #
 # carsMatrix <- ggpairs(
@@ -1097,4 +1271,4 @@ stop_if_params_exist <- function(params) {
 # )
 #
 #
-#}
+# }
