@@ -1,4 +1,4 @@
-#' Put Plot
+#' Insert a plot into a \code{\link{ggmatrix}} object
 #'
 #' Function to place your own plot in the layout.
 #'
@@ -7,15 +7,19 @@
 #' @param i row from the top
 #' @param j column from the left
 #' @keywords hplot
-#' @author Barret Schloerke \email{schloerke@@gmail.com}
+#' @author Barret Schloerke
+#' @seealso \code{\link{getPlot}}
 #' @export
 #' @examples
+#' # Small function to display plots only if it's interactive
+#' p_ <- GGally::print_if_interactive
+#'
 #' custom_car <- ggpairs(mtcars[, c("mpg", "wt", "cyl")], upper = "blank", title = "Custom Example")
 #' # ggplot example taken from example(geom_text)
-#'   plot <- ggplot2::ggplot(mtcars, ggplot2::aes(x=wt, y=mpg, label=rownames(mtcars)))
-#'   plot <- plot +
-#'     ggplot2::geom_text(ggplot2::aes(colour=factor(cyl)), size = 3) +
-#'     ggplot2::scale_colour_discrete(l=40)
+#' plot <- ggplot2::ggplot(mtcars, ggplot2::aes(x = wt, y = mpg, label = rownames(mtcars)))
+#' plot <- plot +
+#'   ggplot2::geom_text(ggplot2::aes(colour = factor(cyl)), size = 3) +
+#'   ggplot2::scale_colour_discrete(l = 40)
 #' custom_car[1, 2] <- plot
 #' personal_plot <- ggally_text(
 #'   "ggpairs allows you\nto put in your\nown plot.\nLike that one.\n <---"
@@ -24,19 +28,27 @@
 #' # custom_car
 #'
 #' # remove plots after creating a plot matrix
-#' custom_car[2,1] <- NULL
-#' custom_car[3,1] <- "blank" # the same as storing null
-#' custom_car[3,2] <- NULL
-#' custom_car
-putPlot <- function(pm, value, i, j){
+#' custom_car[2, 1] <- NULL
+#' custom_car[3, 1] <- "blank" # the same as storing null
+#' custom_car[3, 2] <- NULL
+#' p_(custom_car)
+putPlot <- function(pm, value, i, j) {
   pos <- get_pos(pm, i, j)
   if (is.null(value)) {
-    pm$plots[[pos]] <- make_ggmatrix_plot_obj(wrap("blank", funcArgName = "ggally_blank"))
+    pm$plots[[pos]] <- make_ggmatrix_plot_obj(wrap(
+      "blank",
+      funcArgName = "ggally_blank"
+    ))
   } else if (mode(value) == "character") {
     if (value == "blank") {
-      pm$plots[[pos]] <- make_ggmatrix_plot_obj(wrap("blank", funcArgName = "ggally_blank"))
+      pm$plots[[pos]] <- make_ggmatrix_plot_obj(wrap(
+        "blank",
+        funcArgName = "ggally_blank"
+      ))
     } else {
-      stop("character values (besides 'blank') are not allowed to be stored as plot values.")
+      stop(
+        "character values (besides 'blank') are not allowed to be stored as plot values."
+      )
     }
   } else {
     pm$plots[[pos]] <- value
@@ -45,22 +57,26 @@ putPlot <- function(pm, value, i, j){
   pm
 }
 
-#' getPlot
+#' Subset a \code{\link{ggmatrix}} object
 #'
 #' Retrieves the ggplot object at the desired location.
 #'
-#' @param pm ggmatrix object to select from
+#' @param pm \code{\link{ggmatrix}} object to select from
 #' @param i row from the top
 #' @param j column from the left
 #' @keywords hplot
-#' @author Barret Schloerke \email{schloerke@@gmail.com}
+#' @author Barret Schloerke
 #' @importFrom utils capture.output
+#' @seealso \code{\link{putPlot}}
 #' @export
 #' @examples
-#'  data(tips, package = "reshape")
-#'  plotMatrix2 <- ggpairs(tips[, 3:2], upper = list(combo = "denstrip"))
-#'  plotMatrix2[1, 2]
-getPlot <- function(pm, i, j){
+#' # Small function to display plots only if it's interactive
+#' p_ <- GGally::print_if_interactive
+#'
+#' data(tips)
+#' plotMatrix2 <- ggpairs(tips[, 3:2], upper = list(combo = "denstrip"))
+#' p_(plotMatrix2[1, 2])
+getPlot <- function(pm, i, j) {
   if (FALSE) {
     cat("i: ", i, " j: ", j, "\n")
   }
@@ -76,18 +92,22 @@ getPlot <- function(pm, i, j){
   if (is.null(plotObj)) {
     p <- ggally_blank()
   } else {
-    if (ggplot2::is.ggplot(plotObj)) {
+    if (ggplot2::is_ggplot(plotObj)) {
       p <- plotObj
-
     } else if (inherits(plotObj, "ggmatrix_plot_obj")) {
       fn <- plotObj$fn
       p <- fn(pm$data, plotObj$mapping)
-
     } else if (inherits(plotObj, "legend_guide_box")) {
       p <- plotObj
-
     } else {
-      firstNote <- str_c("Position: i = ", i, ", j = ", j, "\nstr(plotObj):\n", sep = "")
+      firstNote <- str_c(
+        "Position: i = ",
+        i,
+        ", j = ",
+        j,
+        "\nstr(plotObj):\n",
+        sep = ""
+      )
       strObj <- capture.output({
         str(plotObj)
       })
@@ -123,10 +143,10 @@ get_pos_rev <- function(pm, pos) {
 
 
 check_i_j <- function(pm, i, j) {
-  if ( (length(i) > 1) || (mode(i) != "numeric")) {
+  if ((length(i) > 1) || (mode(i) != "numeric")) {
     stop("'i' may only be a single numeric value")
   }
-  if ( (length(j) > 1) || (mode(j) != "numeric")) {
+  if ((length(j) > 1) || (mode(j) != "numeric")) {
     stop("'j' may only be a single numeric value")
   }
 
