@@ -1,7 +1,3 @@
-if (getRversion() >= "2.15.1") {
-  utils::globalVariables(c("cens", "surv", "up", "low"))
-}
-
 #' Survival curves
 #'
 #' This function produces Kaplan-Meier plots using \pkg{ggplot2}.
@@ -84,7 +80,7 @@ if (getRversion() >= "2.15.1") {
 #'       x = c(90, 125, 5, 60),
 #'       y = c(0.8, 0.65, 0.55, 0.30),
 #'       size = 5,
-#'       colour = scales::hue_pal(
+#'       colour = scales::pal_hue(
 #'         h         = c(0, 360) + 15,
 #'         c         = 100,
 #'         l         = 65,
@@ -95,25 +91,26 @@ if (getRversion() >= "2.15.1") {
 #'     ggplot2::guides(color = "none", linetype = "none"))
 #' }
 ggsurv <- function(
-    s,
-    CI = "def",
-    plot.cens = TRUE,
-    surv.col = "gg.def",
-    cens.col = "gg.def",
-    lty.est = 1,
-    lty.ci = 2,
-    size.est = 0.5,
-    size.ci = size.est,
-    cens.size = 2,
-    cens.shape = 3,
-    back.white = FALSE,
-    xlab = "Time",
-    ylab = "Survival",
-    main = "",
-    order.legend = TRUE) {
-  require_namespaces(c("survival", "scales"))
+  s,
+  CI = "def",
+  plot.cens = TRUE,
+  surv.col = "gg.def",
+  cens.col = "gg.def",
+  lty.est = 1,
+  lty.ci = 2,
+  size.est = 0.5,
+  size.ci = size.est,
+  cens.size = 2,
+  cens.shape = 3,
+  back.white = FALSE,
+  xlab = "Time",
+  ylab = "Survival",
+  main = "",
+  order.legend = TRUE
+) {
+  rlang::check_installed(c("survival", "scales"))
 
-  strata <- ifelse(is.null(s$strata) == TRUE, 1, length(s$strata))
+  strata <- ifelse(is.null(s$strata), 1, length(s$strata))
   stopifnot(length(surv.col) == 1 | length(surv.col) == strata)
   stopifnot(length(lty.est) == 1 | length(lty.est) == strata)
 
@@ -124,45 +121,59 @@ ggsurv <- function(
   }
 
   pl <- fn(
-    s, CI, plot.cens, surv.col,
-    cens.col, lty.est, lty.ci, size.est, size.ci, cens.size,
-    cens.shape, back.white, xlab,
-    ylab, main, strata, order.legend
+    s,
+    CI,
+    plot.cens,
+    surv.col,
+    cens.col,
+    lty.est,
+    lty.ci,
+    size.est,
+    size.ci,
+    cens.size,
+    cens.shape,
+    back.white,
+    xlab,
+    ylab,
+    main,
+    strata,
+    order.legend
   )
   pl
 }
 
 # survival function for single survival
 ggsurv_s <- function(
-    s,
-    CI = "def",
-    plot.cens = TRUE,
-    surv.col = "gg.def",
-    cens.col = "gg.def",
-    lty.est = 1,
-    lty.ci = 2,
-    size.est = 0.5,
-    size.ci = size.est,
-    cens.size = 2,
-    cens.shape = 3,
-    back.white = FALSE,
-    xlab = "Time",
-    ylab = "Survival",
-    main = "",
-    strata = 1,
-    order.legend = TRUE) {
+  s,
+  CI = "def",
+  plot.cens = TRUE,
+  surv.col = "gg.def",
+  cens.col = "gg.def",
+  lty.est = 1,
+  lty.ci = 2,
+  size.est = 0.5,
+  size.ci = size.est,
+  cens.size = 2,
+  cens.shape = 3,
+  back.white = FALSE,
+  xlab = "Time",
+  ylab = "Survival",
+  main = "",
+  strata = 1,
+  order.legend = TRUE
+) {
   dat <- data.frame(
     time = c(0, s$time),
     surv = c(1, s$surv),
-    up   = c(1, s$upper),
-    low  = c(1, s$lower),
+    up = c(1, s$upper),
+    low = c(1, s$lower),
     cens = c(0, s$n.censor)
   )
-  dat.cens <- subset(dat, cens != 0)
+  dat.cens <- dat[!is.na(dat$cens) & dat$cens != 0, ]
 
   col <- ifelse(surv.col == "gg.def", "black", surv.col)
 
-  pl <- ggplot(dat, aes(x = time, y = surv)) +
+  pl <- ggplot(dat, aes(x = .data$time, y = .data$surv)) +
     geom_step(col = col, lty = lty.est, linewidth = size.est) +
     xlab(xlab) +
     ylab(ylab) +
@@ -170,8 +181,18 @@ ggsurv_s <- function(
 
   if (identical(CI, TRUE) | identical(CI, "def")) {
     pl <- pl +
-      geom_step(aes(y = up), color = col, lty = lty.ci, linewidth = size.ci) +
-      geom_step(aes(y = low), color = col, lty = lty.ci, linewidth = size.ci)
+      geom_step(
+        aes(y = .data$up),
+        color = col,
+        lty = lty.ci,
+        linewidth = size.ci
+      ) +
+      geom_step(
+        aes(y = .data$low),
+        color = col,
+        lty = lty.ci,
+        linewidth = size.ci
+      )
   }
 
   if (identical(plot.cens, TRUE)) {
@@ -180,13 +201,14 @@ ggsurv_s <- function(
     }
     col <- ifelse(cens.col == "gg.def", "red", cens.col)
 
-    pl <- pl + geom_point(
-      data    = dat.cens,
-      mapping = aes(y = surv),
-      shape   = cens.shape,
-      col     = col,
-      size    = cens.size
-    )
+    pl <- pl +
+      geom_point(
+        data = dat.cens,
+        mapping = aes(y = .data$surv),
+        shape = cens.shape,
+        col = col,
+        size = cens.size
+      )
   }
 
   if (back.white == TRUE) {
@@ -198,23 +220,24 @@ ggsurv_s <- function(
 
 # survival function for multiple survivals
 ggsurv_m <- function(
-    s,
-    CI = "def",
-    plot.cens = TRUE,
-    surv.col = "gg.def",
-    cens.col = "gg.def",
-    lty.est = 1,
-    lty.ci = 2,
-    size.est = 0.5,
-    size.ci = size.est,
-    cens.size = 2,
-    cens.shape = 3,
-    back.white = FALSE,
-    xlab = "Time",
-    ylab = "Survival",
-    main = "",
-    strata = length(s$strata),
-    order.legend = TRUE) {
+  s,
+  CI = "def",
+  plot.cens = TRUE,
+  surv.col = "gg.def",
+  cens.col = "gg.def",
+  lty.est = 1,
+  lty.ci = 2,
+  size.est = 0.5,
+  size.ci = size.est,
+  cens.size = 2,
+  cens.shape = 3,
+  back.white = FALSE,
+  xlab = "Time",
+  ylab = "Survival",
+  main = "",
+  strata = length(s$strata),
+  order.legend = TRUE
+) {
   n <- s$strata
 
   has_many <- all(grepl(",", names(s$strata)))
@@ -266,19 +289,19 @@ ggsurv_m <- function(
   for (i in 1:strata) {
     indI <- (n.ind[i] + 1):n.ind[i + 1]
     gr.df[[i]] <- data.frame(
-      time  = c(0, s$time[indI]),
-      surv  = c(1, s$surv[indI]),
-      up    = c(1, s$upper[indI]),
-      low   = c(1, s$lower[indI]),
-      cens  = c(0, s$n.censor[indI]),
+      time = c(0, s$time[indI]),
+      surv = c(1, s$surv[indI]),
+      up = c(1, s$upper[indI]),
+      low = c(1, s$lower[indI]),
+      cens = c(0, s$n.censor[indI]),
       group = rep(groups[i], n[i] + 1)
     )
   }
 
   dat <- do.call(rbind, gr.df)
 
-  pl <- ggplot(dat, aes(x = time, y = surv, group = group)) +
-    geom_step(aes(col = group, lty = group), linewidth = size.est) +
+  pl <- ggplot(dat, aes(x = .data$time, y = .data$surv, group = .data$group)) +
+    geom_step(aes(col = .data$group, lty = .data$group), linewidth = size.est) +
     xlab(xlab) +
     ylab(ylab) +
     ggtitle(main)
@@ -308,13 +331,21 @@ ggsurv_m <- function(
       surv.col
     }
     pl <- pl +
-      geom_step(aes(y = up, lty = group, col = group), lty = stepLty, linewidth = size.ci) +
-      geom_step(aes(y = low, lty = group, col = group), lty = stepLty, linewidth = size.ci)
+      geom_step(
+        aes(y = .data$up, lty = .data$group, col = .data$group),
+        lty = stepLty,
+        linewidth = size.ci
+      ) +
+      geom_step(
+        aes(y = .data$low, lty = .data$group, col = .data$group),
+        lty = stepLty,
+        linewidth = size.ci
+      )
   }
 
   if (identical(plot.cens, TRUE)) {
-    dat.cens <- subset(dat, cens != 0)
-    dat.cens <- subset(dat.cens, group != "PKD")
+    dat.cens <- dat[!is.na(dat$cens) & dat$cens != 0, ]
+    dat.cens <- dat.cens[!is.na(dat.cens$group) & dat.cens$group != "PKD", ]
 
     if (nrow(dat.cens) == 0) {
       stop("There are no censored observations")
@@ -322,45 +353,49 @@ ggsurv_m <- function(
     if (length(cens.col) == 1) {
       if (identical(cens.col, "gg.def")) {
         # match the colors of the lines
-        pl <- pl + geom_point(
-          data = dat.cens,
-          mapping = aes(y = surv, col = group),
-          shape = cens.shape,
-          size = cens.size,
-          show.legend = FALSE
-        )
+        pl <- pl +
+          geom_point(
+            data = dat.cens,
+            mapping = aes(y = .data$surv, col = .data$group),
+            shape = cens.shape,
+            size = cens.size,
+            show.legend = FALSE
+          )
       } else {
         # supply the raw color value
-        pl <- pl + geom_point(
-          data    = dat.cens,
-          mapping = aes(y = surv),
-          shape   = cens.shape,
-          color   = cens.col,
-          size    = cens.size
-        )
+        pl <- pl +
+          geom_point(
+            data = dat.cens,
+            mapping = aes(y = .data$surv),
+            shape = cens.shape,
+            color = cens.col,
+            size = cens.size
+          )
       }
     } else if (length(cens.col) > 0) {
       # if (!(identical(cens.col, surv.col) || is.null(cens.col))) {
       #   warning ("Color scales for survival curves and censored points don't match.\nOnly one color scale can be used. Defaulting to surv.col")
       # }
 
-
       if (!identical(cens.col, "gg.def")) {
         if (length(cens.col) != strata) {
-          warning("Color scales for censored points don't match the number of groups. Defaulting to ggplot2 default color scale")
+          warning(
+            "Color scales for censored points don't match the number of groups. Defaulting to ggplot2 default color scale"
+          )
           cens.col <- "gg.def"
         }
       }
 
       if (identical(cens.col, "gg.def")) {
         # match the group color value
-        pl <- pl + geom_point(
-          data = dat.cens,
-          mapping = aes(y = surv, col = group),
-          shape = cens.shape,
-          show.legend = FALSE,
-          size = cens.size
-        )
+        pl <- pl +
+          geom_point(
+            data = dat.cens,
+            mapping = aes(y = .data$surv, col = .data$group),
+            shape = cens.shape,
+            show.legend = FALSE,
+            size = cens.size
+          )
       } else {
         # custom colors and maybe custom shape
         uniqueGroupVals <- levels(dat.cens$group)
@@ -369,24 +404,29 @@ ggsurv_m <- function(
         }
 
         if (length(cens.shape) != strata) {
-          warning("The length of the censored shapes does not match the number of groups (or 1). Defaulting shape = 3 (+)")
+          warning(
+            "The length of the censored shapes does not match the number of groups (or 1). Defaulting shape = 3 (+)"
+          )
           cens.shape <- rep(3, strata)
         }
         for (i in seq_along(uniqueGroupVals)) {
           groupVal <- uniqueGroupVals[i]
-          dtGroup <- subset(dat.cens, group == groupVal)
+          dtGroup <- dat.cens[
+            !is.na(dat.cens$group) & dat.cens$group == groupVal,
+          ]
           if (nrow(dtGroup) == 0) {
             next
           }
 
-          pl <- pl + geom_point(
-            data = dtGroup,
-            mapping = aes(y = surv),
-            color = I(cens.col[i]),
-            shape = cens.shape[i],
-            show.legend = FALSE,
-            size = cens.size
-          )
+          pl <- pl +
+            geom_point(
+              data = dtGroup,
+              mapping = aes(y = .data$surv),
+              color = I(cens.col[i]),
+              shape = cens.shape[i],
+              show.legend = FALSE,
+              size = cens.size
+            )
         }
       }
     }
@@ -396,10 +436,11 @@ ggsurv_m <- function(
     pl <- pl + theme_bw()
   }
 
-  pl <- pl + labs(
-    color = gr.name,
-    linetype = gr.name
-  )
+  pl <- pl +
+    labs(
+      color = gr.name,
+      linetype = gr.name
+    )
 
   pl
 }
