@@ -1,4 +1,3 @@
-context("gg-plots")
 # This file takes too long
 testthat::skip_on_cran()
 
@@ -8,12 +7,18 @@ nas <- subset(nasa, x <= 2 & y == 1)
 
 test_that("denstrip", {
   expect_message(
-    suppressWarnings(print(ggally_denstrip(tips, mapping = aes(!!as.name("sex"), !!as.name("tip"))))),
+    suppressWarnings(print(ggally_denstrip(
+      tips,
+      mapping = aes(!!as.name("sex"), !!as.name("tip"))
+    ))),
     "`stat_bin()` using `bins = 30`",
     fixed = TRUE
   )
   expect_message(
-    suppressWarnings(print(ggally_denstrip(tips, mapping = aes(!!as.name("tip"), !!as.name("sex"))))),
+    suppressWarnings(print(ggally_denstrip(
+      tips,
+      mapping = aes(!!as.name("tip"), !!as.name("sex"))
+    ))),
     "`stat_bin()` using `bins = 30`",
     fixed = TRUE
   )
@@ -23,35 +28,46 @@ test_that("denstrip", {
 test_that("density", {
   p <- ggally_density(
     tips,
-    mapping = ggplot2::aes(x = !!as.name("total_bill"), y = !!as.name("tip"), fill = after_stat(level))
-  ) + ggplot2::scale_fill_gradient(breaks = c(0.05, 0.1, 0.15, 0.2))
-  expect_equal(p$labels$fill, "level")
+    mapping = ggplot2::aes(
+      x = !!as.name("total_bill"),
+      y = !!as.name("tip"),
+      fill = after_stat(level)
+    )
+  ) +
+    ggplot2::scale_fill_gradient(breaks = c(0.05, 0.1, 0.15, 0.2))
+  expect_equal(get_labs(p)$fill, "level")
 })
 
 test_that("cor", {
   ti <- tips
   class(ti) <- c("NOTFOUND", "data.frame")
-  p <- ggally_cor(ti, ggplot2::aes(x = total_bill, y = tip, color = day), use = "complete.obs")
-  expect_equal(mapping_string(get("mapping", envir = p$layers[[2]])$colour), "labelp")
+  p <- ggally_cor(ti, ggplot2::aes(x = total_bill, y = tip, color = day))
+  expect_equal(
+    mapping_string(get("mapping", envir = p$layers[[2]])$colour),
+    "labelp"
+  )
 
   p <- ggally_cor(
     ti,
-    ggplot2::aes(x = total_bill, y = tip, color = I("blue")),
-    use = "complete.obs"
+    ggplot2::aes(x = total_bill, y = tip, color = I("blue"))
+  )
+  expect_equal(
+    mapping_string(get("mapping", envir = p$layers[[1]])$colour),
+    "I(\"blue\")"
   )
-  expect_equal(mapping_string(get("mapping", envir = p$layers[[1]])$colour), "I(\"blue\")")
 
   expect_err <- function(..., msg = NULL) {
     expect_error(
       ggally_cor(
-        ti, ggplot2::aes(x = total_bill, y = tip),
+        ti,
+        ggplot2::aes(x = total_bill, y = tip),
         ...
       ),
       msg
     )
   }
 
-  vdiffr::expect_doppelganger(
+  ggally_expect_doppelganger(
     "cor-green",
     ggally_cor(ti, ggplot2::aes(x = total_bill, y = tip, color = I("green")))
   )
@@ -70,6 +86,7 @@ test_that("cor", {
       msg
     )
   }
+
   expect_warn(ti2, "Removing 1 row that")
   expect_warn(ti3, "Removed 3 rows containing")
 
@@ -93,8 +110,32 @@ test_that("diagAxis", {
   pDat1 <- get("data", envir = p$layers[[2]])
   attr(pDat1, "out.attrs") <- NULL
   testDt1 <- data.frame(
-    xPos = c(0.076, 0.076, 0.076, 0.076, 0.076, 0.076, 0.500, 1.000, 1.500, 2.000, 2.500),
-    yPos = c(0.500, 1.000, 1.500, 2.000, 2.500, 0.076, 0.076, 0.076, 0.076, 0.076, 0.076),
+    xPos = c(
+      0.076,
+      0.076,
+      0.076,
+      0.076,
+      0.076,
+      0.076,
+      0.500,
+      1.000,
+      1.500,
+      2.000,
+      2.500
+    ),
+    yPos = c(
+      0.500,
+      1.000,
+      1.500,
+      2.000,
+      2.500,
+      0.076,
+      0.076,
+      0.076,
+      0.076,
+      0.076,
+      0.076
+    ),
     lab = as.character(c(0.5, 1, 1.5, 2, 2.5, 0, 0.5, 1, 1.5, 2, 2.5)),
     hjust = c(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 0.5, 0.5, 0.5, 0.5),
     vjust = c(0.5, 0.5, 0.5, 0.5, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0),
@@ -113,31 +154,39 @@ test_that("diagAxis", {
   )
   expect_equal(pDat2, testDt2)
 
-
   expect_error(
     {
       ggally_diagAxis(iris, mapping = ggplot2::aes(y = Sepal.Length))
     },
     "mapping\\$x is null."
-  ) # nolint
+  )
 })
 
 test_that("dates", {
   class(nas) <- c("NOTFOUND", "data.frame")
   p <- ggally_cor(nas, ggplot2::aes(x = date, y = ozone))
-  expect_equal(get("aes_params", envir = p$layers[[1]])$label, "Corr:\n0.278***")
-  p <- ggally_barDiag(nas, ggplot2::aes(x = date))
+  expect_equal(
+    get("aes_params", envir = p$layers[[1]])$label,
+    "Corr:\n0.278***"
+  )
+  p <- ggally_barDiag(nas, ggplot2::aes(x = date), bins = 10)
   expect_equal(mapping_string(p$mapping$x), "date")
-  expect_equal(as.character(p$labels$y), "count")
+  expect_equal(as.character(get_labs(p)$y), "count")
 })
 
 test_that("cor stars are aligned", {
-  p <- ggally_cor(iris, ggplot2::aes(x = Sepal.Length, y = Petal.Width, color = as.factor(Species)))
+  p <- ggally_cor(
+    iris,
+    ggplot2::aes(x = Sepal.Length, y = Petal.Width, color = as.factor(Species))
+  )
   expect_equal(get("aes_params", envir = p$layers[[1]])$label, "Corr: 0.818***")
   # expect_equal(get("aes_params", envir = p$layers[[1]])$family, "mono")
 
   labels <- eval_data_col(p$layers[[2]]$data, p$layers[[2]]$mapping$label)
-  expect_equal(as.character(labels), c("    setosa: 0.278.  ", "versicolor: 0.546***", " virginica: 0.281*  "))
+  expect_equal(
+    as.character(labels),
+    c("    setosa: 0.278.  ", "versicolor: 0.546***", " virginica: 0.281*  ")
+  )
 })
 
 test_that("ggally_statistic handles factors", {
@@ -145,49 +194,81 @@ test_that("ggally_statistic handles factors", {
     scales::number(chisq.test(x, y)$p.value, accuracy = .001)
   }
   expect_silent({
-    p <- ggally_statistic(tips, aes(x = sex, y = day), text_fn = simple_chisq, title = "Chi^2")
+    p <- ggally_statistic(
+      tips,
+      aes(x = sex, y = day),
+      text_fn = simple_chisq,
+      title = "Chi^2"
+    )
   })
 })
 
 test_that("rescale", {
-  p <- ggally_densityDiag(tips, mapping = ggplot2::aes(x = day), rescale = FALSE)
-  expect_true(p$labels$y == "density")
-  vdiffr::expect_doppelganger("rescale-false", p)
+  p <- ggally_densityDiag(
+    tips,
+    mapping = ggplot2::aes(x = day),
+    rescale = FALSE
+  )
+  expect_true(get_labs(p)$y == "density")
+  ggally_expect_doppelganger("rescale-false", p)
 
   p <- ggally_densityDiag(tips, mapping = ggplot2::aes(x = day), rescale = TRUE)
-  expect_true(!identical(p$labels$y, "density"))
-  vdiffr::expect_doppelganger("rescale-true", p)
+  expect_true(!identical(get_labs(p)$y, "density"))
+  ggally_expect_doppelganger("rescale-true", p)
 
+  p <- ggally_barDiag(
+    tips,
+    mapping = ggplot2::aes(x = tip),
+    binwidth = 0.25,
+    rescale = FALSE
+  )
+  expect_true(get_labs(p)$y == "count")
+  ggally_expect_doppelganger("rescale-false-binwidth", p)
 
-  p <- ggally_barDiag(tips, mapping = ggplot2::aes(x = tip), binwidth = 0.25, rescale = FALSE)
-  expect_true(p$labels$y == "count")
-  vdiffr::expect_doppelganger("rescale-false-binwidth", p)
-
-  p <- ggally_barDiag(tips, mapping = ggplot2::aes(x = tip), binwidth = 0.25, rescale = TRUE)
-  expect_true(!identical(p$labels$y, "count"))
-  vdiffr::expect_doppelganger("rescale-true-binwidth", p)
+  p <- ggally_barDiag(
+    tips,
+    mapping = ggplot2::aes(x = tip),
+    binwidth = 0.25,
+    rescale = TRUE
+  )
+  expect_true(!identical(get_labs(p)$y, "count"))
+  ggally_expect_doppelganger("rescale-true-binwidth", p)
 })
 
 
-
 test_that("shrink", {
-  p <- ggally_smooth_loess(iris, mapping = ggplot2::aes(Sepal.Width, Petal.Length))
+  p <- ggally_smooth_loess(
+    iris,
+    mapping = ggplot2::aes(Sepal.Width, Petal.Length)
+  )
   expect_true(!is.null(p$coordinates$limits$y))
-  vdiffr::expect_doppelganger("shrink-true", p)
+  ggally_expect_doppelganger("shrink-true", p)
 
-  p <- ggally_smooth_loess(iris, mapping = ggplot2::aes(Sepal.Width, Petal.Length), shrink = FALSE)
+  p <- ggally_smooth_loess(
+    iris,
+    mapping = ggplot2::aes(Sepal.Width, Petal.Length),
+    shrink = FALSE
+  )
   expect_true(is.null(p$coordinates$limits$y))
-  vdiffr::expect_doppelganger("shrink-false", p)
+  ggally_expect_doppelganger("shrink-false", p)
 })
 
 test_that("smooth_se", {
-  p <- ggally_smooth_loess(iris, mapping = ggplot2::aes(Sepal.Width, Petal.Length), se = TRUE)
+  p <- ggally_smooth_loess(
+    iris,
+    mapping = ggplot2::aes(Sepal.Width, Petal.Length),
+    se = TRUE
+  )
   expect_equal(p$layers[[2]]$stat_params$se, TRUE)
-  vdiffr::expect_doppelganger("smooth-se-true", p)
+  ggally_expect_doppelganger("smooth-se-true", p)
 
-  p <- ggally_smooth_loess(iris, mapping = ggplot2::aes(Sepal.Width, Petal.Length), se = FALSE)
+  p <- ggally_smooth_loess(
+    iris,
+    mapping = ggplot2::aes(Sepal.Width, Petal.Length),
+    se = FALSE
+  )
   expect_equal(p$layers[[2]]$stat_params$se, FALSE)
-  vdiffr::expect_doppelganger("smooth-se-false", p)
+  ggally_expect_doppelganger("smooth-se-false", p)
 })
 
 
@@ -196,46 +277,51 @@ test_that("ggally_count", {
     as.data.frame(Titanic),
     ggplot2::aes(x = Class, y = Survived, weight = Freq)
   )
-  vdiffr::expect_doppelganger("titanic-count", p)
+  ggally_expect_doppelganger("titanic-count", p)
 
   p <- ggally_count(
     as.data.frame(Titanic),
     ggplot2::aes(x = Class, y = Survived, weight = Freq),
     fill = "red"
   )
-  vdiffr::expect_doppelganger("titanic-count-red", p)
+  ggally_expect_doppelganger("titanic-count-red", p)
 
   p <- ggally_count(
     as.data.frame(Titanic),
     ggplot2::aes(x = Class, y = Survived, weight = Freq, fill = Sex)
   )
-  vdiffr::expect_doppelganger("titanic-count-sex", p)
+  ggally_expect_doppelganger("titanic-count-sex", p)
 
   p <- ggally_count(
     as.data.frame(Titanic),
     ggplot2::aes(x = Class, y = Survived, weight = Freq, fill = Class)
   )
-  vdiffr::expect_doppelganger("titanic-count-class", p)
+  ggally_expect_doppelganger("titanic-count-class", p)
 
   p <- ggally_count(
     as.data.frame(Titanic),
-    ggplot2::aes(x = Survived, y = interaction(Sex, Age), weight = Freq, fill = Class)
+    ggplot2::aes(
+      x = Survived,
+      y = interaction(Sex, Age),
+      weight = Freq,
+      fill = Class
+    )
   )
-  vdiffr::expect_doppelganger("titanic-count-interaction", p)
+  ggally_expect_doppelganger("titanic-count-interaction", p)
 
   # check that y character vectors are rendering
   p <- ggally_count(
     as.data.frame(Titanic),
     ggplot2::aes(x = Class, y = toupper(Survived), weight = Freq, fill = Class)
   )
-  vdiffr::expect_doppelganger("titanic-count-toupper", p)
+  ggally_expect_doppelganger("titanic-count-toupper", p)
 
   # check countDiag
   p <- ggally_countDiag(
     as.data.frame(Titanic),
     ggplot2::aes(x = Survived, weight = Freq, fill = Class)
   )
-  vdiffr::expect_doppelganger("titanic-count-diag", p)
+  ggally_expect_doppelganger("titanic-count-diag", p)
 
   # change size of tiles
   p <- ggally_count(
@@ -243,13 +329,31 @@ test_that("ggally_count", {
     ggplot2::aes(x = Class, y = Survived, weight = Freq, fill = Class),
     x.width = .5
   )
-  vdiffr::expect_doppelganger("titanic-count-diag-class", p)
+  ggally_expect_doppelganger("titanic-count-diag-class", p)
 
   # no warnings expected if na.rm = TRUE
   p <- ggally_count(
     as.data.frame(Titanic),
-    ggplot2::aes(x = interaction(Class, Age), y = Survived, weight = Freq, fill = Class),
+    ggplot2::aes(
+      x = interaction(Class, Age),
+      y = Survived,
+      weight = Freq,
+      fill = Class
+    ),
     na.rm = TRUE
   )
-  vdiffr::expect_doppelganger("titanic-count-diag-interaction", p)
+  ggally_expect_doppelganger("titanic-count-diag-interaction", p)
+})
+
+
+test_that("deprecated ggally_cor variables are deprecated", {
+  lifecycle::expect_deprecated(
+    ggally_cor(tips, mapping = aes(total_bill, tip), use = "something")
+  )
+  lifecycle::expect_deprecated(
+    ggally_cor(tips, mapping = aes(total_bill, tip), alignPercent = 0.5)
+  )
+  lifecycle::expect_deprecated(
+    ggally_cor(tips, mapping = aes(total_bill, tip), displayGrid = FALSE)
+  )
 })
