@@ -1,13 +1,19 @@
-
-context("ggmatrix")
 data(tips)
 
 test_that("stops", {
+  expect_error(
+    ggmatrix(plots = matrix(), nrow = 2, ncol = 3),
+    "'plots' must be a list()"
+  )
 
-  expect_error(ggmatrix(plots = matrix(), nrow = 2, ncol = 3), "'plots' must be a list()")
-
-  expect_error(ggmatrix(plots = list(), nrow = "2", ncol = 3), "'nrow' must be a numeric value")
-  expect_error(ggmatrix(plots = list(), nrow = 2, ncol = "3"), "'ncol' must be a numeric value")
+  expect_error(
+    ggmatrix(plots = list(), nrow = "2", ncol = 3),
+    "'nrow' must be a numeric value"
+  )
+  expect_error(
+    ggmatrix(plots = list(), nrow = 2, ncol = "3"),
+    "'ncol' must be a numeric value"
+  )
 
   expect_error(
     ggmatrix(plots = list(), nrow = c(2, 3), ncol = 3),
@@ -17,7 +23,6 @@ test_that("stops", {
     ggmatrix(plots = list(), nrow = 2, ncol = c(2, 3)),
     "'ncol' must be a single numeric value"
   )
-
 })
 
 
@@ -26,9 +31,12 @@ test_that("expression labels", {
   exprs <- c("alpha[0]", "gamma[x + y ^ z]")
 
   p <- ggpairs(tips, 1:2, columnLabels = exprs, labeller = "label_parsed")
-  vdiffr::expect_doppelganger("expression-labels", p)
+  ggally_expect_doppelganger("expression-labels", p)
 
-  expect_error(print(ggpairs(tips, 1:2, columnLabels = expression(alpha, beta))), "xAxisLabels")
+  expect_error(
+    print(ggpairs(tips, 1:2, columnLabels = expression(alpha, beta))),
+    "xAxisLabels"
+  )
 })
 
 
@@ -41,7 +49,8 @@ test_that("byrow", {
   }
   a <- ggmatrix(
     plotList,
-    2, 3,
+    2,
+    3,
     c("A", "B", "C"),
     c("D", "E"),
     byrow = TRUE
@@ -57,7 +66,8 @@ test_that("byrow", {
 
   a <- ggmatrix(
     plotList,
-    2, 3,
+    2,
+    3,
     c("A", "B", "C"),
     c("D", "E"),
     byrow = FALSE
@@ -70,7 +80,6 @@ test_that("byrow", {
     }
   }
   a
-
 })
 
 test_that("missing plot", {
@@ -82,19 +91,18 @@ test_that("missing plot", {
   }
   a <- ggmatrix(
     plotList,
-    2, 3,
+    2,
+    3,
     c("A", "B", "C"),
     c("D", "E"),
     byrow = TRUE
   )
   # reaches code where there are more cells than plots
-  vdiffr::expect_doppelganger("not-enough-plots", a)
+  ggally_expect_doppelganger("not-enough-plots", a)
 
   expect_equal(a[1, 1]$ggally_check_val, 1)
   expect_equal(a[1, 3]$ggally_check_val, 3)
   expect_equal(a[2, 2]$ggally_check_val, 5)
-
-
 })
 
 
@@ -117,23 +125,25 @@ test_that("str.ggmatrix", {
 test_that("blank", {
   pm <- ggpairs(tips, 1:2)
   pm[1, 2] <- "blank"
-  vdiffr::expect_doppelganger("blank-1_2", pm)
+  ggally_expect_doppelganger("blank-1_2", pm)
 
   pm[2, 1] <- NULL
-  vdiffr::expect_doppelganger("blank-1_2-2_1", pm)
+  ggally_expect_doppelganger("blank-1_2-2_1", pm)
 
   expect_equal(length(pm$plots), 4)
 
-  expect_error({
-    pm[2, 2] <- "not blank"
-  }, "character values \\(besides 'blank'\\)") # nolint
+  expect_error(
+    {
+      pm[2, 2] <- "not blank"
+    },
+    "character values \\(besides 'blank'\\)"
+  )
 })
 
 test_that("proportions", {
   pm <- ggpairs(iris, 1:2, mapping = ggplot2::aes(color = Species))
   pm[2, 2] <- pm[2, 2] + ggplot2::coord_flip()
 
-
   pm2 <- ggmatrix(
     data = iris,
     pm$plots,
@@ -143,7 +153,7 @@ test_that("proportions", {
     yProportions = c(1, 2),
     title = "big plot, small marginals"
   )
-  vdiffr::expect_doppelganger("proportions", pm2)
+  ggally_expect_doppelganger("proportions", pm2)
 
   # turn on progress for a quick plot
   # TODO - turn test back on when it uses message properly
@@ -156,10 +166,10 @@ test_that("ggmatrix_gtable progress", {
   expect_silent({
     pg <- ggmatrix_gtable(pm)
   })
-  expect_warning({
+  lifecycle::expect_deprecated({
     ggmatrix_gtable(pm, progress = TRUE)
   })
-  expect_warning({
+  lifecycle::expect_deprecated({
     ggmatrix_gtable(pm, progress_format = "asdfasdf :plot_i")
   })
 })
@@ -173,18 +183,25 @@ test_that("ggmatrix_gtable progress", {
 # }
 #
 
-
 test_that("ggmatrix proportions", {
-
-  expect_error({
-    ggmatrix_proportions("not auto", tips, 1:ncol(tips))
-  }, "need to be non-NA")
-  expect_error({
-    ggmatrix_proportions(NA, tips, 1:ncol(tips))
-  }, "need to be non-NA")
-  expect_error({
-    ggmatrix_proportions(c(1, NA, 1, 1, 1, 1, 1), tips, 1:ncol(tips))
-  }, "need to be non-NA")
+  expect_error(
+    {
+      ggmatrix_proportions("not auto", tips, 1:ncol(tips))
+    },
+    "need to be non-NA"
+  )
+  expect_error(
+    {
+      ggmatrix_proportions(NA, tips, 1:ncol(tips))
+    },
+    "need to be non-NA"
+  )
+  expect_error(
+    {
+      ggmatrix_proportions(c(1, NA, 1, 1, 1, 1, 1), tips, 1:ncol(tips))
+    },
+    "need to be non-NA"
+  )
 
   expect_equal(
     ggmatrix_proportions("auto", tips, 1:ncol(tips)),
