@@ -1,5 +1,3 @@
-context("ggnostic")
-
 test_that("fn_switch", {
   fn1 <- function(data, mapping, ...) {
     return(1)
@@ -24,7 +22,6 @@ test_that("fn_switch", {
     expect_equal(fn(dummy_dt, mapping), i)
   }
 
-
   fn <- fn_switch(list(A = fn1, default = fn5), "value")
   expect_equal(fn(dummy_dt, ggplot2::aes(value = !!as.name("A"))), 1)
   expect_equal(fn(dummy_dt, ggplot2::aes(value = !!as.name("B"))), 5)
@@ -32,7 +29,10 @@ test_that("fn_switch", {
 
   fn <- fn_switch(list(A = fn1), "value")
   expect_equal(fn(dummy_dt, ggplot2::aes(value = !!as.name("A"))), 1)
-  expect_error(fn(dummy_dt, ggplot2::aes(value = !!as.name("B"))), "function could not be found")
+  expect_error(
+    fn(dummy_dt, ggplot2::aes(value = !!as.name("B"))),
+    "function could not be found"
+  )
 })
 
 test_that("model_beta_label", {
@@ -55,11 +55,20 @@ test_that("ggnostic mtcars", {
   pm <- ggnostic(
     mod,
     mapping = ggplot2::aes(),
-    columnsY = c("mpg", ".fitted", ".se.fit", ".resid", ".std.resid", ".sigma", ".hat", ".cooksd"),
+    columnsY = c(
+      "mpg",
+      ".fitted",
+      ".se.fit",
+      ".resid",
+      ".std.resid",
+      ".sigma",
+      ".hat",
+      ".cooksd"
+    ),
     continuous = continuous_type,
     progress = FALSE
   )
-  vdiffr::expect_doppelganger("custom-y", pm)
+  ggally_expect_doppelganger("custom-y", pm)
 
   pm <- ggnostic(
     mod,
@@ -68,11 +77,10 @@ test_that("ggnostic mtcars", {
     continuous = continuous_type,
     progress = FALSE
   )
-  vdiffr::expect_doppelganger("legend", pm)
+  ggally_expect_doppelganger("legend", pm)
 })
 
 
-
 test_that("error checking", {
   get_cols <- function(cols) {
     match_nostic_columns(
@@ -82,15 +90,21 @@ test_that("error checking", {
     )
   }
 
-  expect_equivalent(
+  expect_equal(
     get_cols(c(".resid", ".sig", ".hat", ".c")),
     c(".resid", ".sigma", ".hat", ".cooksd")
   )
 
   expect_error(
     get_cols(c(
-      "not_there", ".fitted", ".se.fit", ".resid",
-      ".std.resid", ".sigma", ".hat", ".cooksd"
+      "not_there",
+      ".fitted",
+      ".se.fit",
+      ".resid",
+      ".std.resid",
+      ".sigma",
+      ".hat",
+      ".cooksd"
     )),
     "Could not match 'columnsY'"
   )
