@@ -1,4 +1,3 @@
-context("ggsurv")
 suppressMessages(require(survival))
 suppressMessages(require(scales))
 lung <- survival::lung
@@ -10,31 +9,33 @@ sf.kid <- survival::survfit(Surv(time, status) ~ disease, data = kidney)
 test_that("single", {
   a <- ggsurv(sf.lung)
 
-  expect_equivalent(mapping_string(a$mapping$x), "time")
-  expect_equivalent(mapping_string(a$mapping$y), "surv")
+  expect_equal(mapping_string(a$mapping$x), "time")
+  expect_equal(mapping_string(a$mapping$y), "surv")
 
-  expect_true(is.null(a$labels$group))
-  expect_true(is.null(a$labels$colour))
-  expect_true(is.null(a$labels$linetype))
+  labs <- get_labs(a)
+  expect_true(is.null(labs$group))
+  expect_true(is.null(labs$colour))
+  expect_true(is.null(labs$linetype))
 })
 
 test_that("multiple", {
   a <- ggsurv(sf.kid)
 
-  expect_equivalent(mapping_string(a$mapping$x), "time")
-  expect_equivalent(mapping_string(a$mapping$y), "surv")
+  expect_equal(mapping_string(a$mapping$x), "time")
+  expect_equal(mapping_string(a$mapping$y), "surv")
 
-  expect_true(!is.null(a$labels$group))
-  expect_true(!is.null(a$labels$colour))
-  expect_true(!is.null(a$labels$linetype))
+  labs <- get_labs(a)
+  expect_true(!is.null(labs$group))
+  expect_true(!is.null(labs$colour))
+  expect_true(!is.null(labs$linetype))
 })
 
 test_that("adjust plot", {
   a <- ggsurv(sf.kid, plot.cens = FALSE)
-  expect_equivalent(length(a$layers), 1)
+  expect_equal(length(a$layers), 1)
 
   a <- ggsurv(sf.kid, plot.cens = TRUE)
-  expect_equivalent(length(a$layers), 2)
+  expect_equal(length(a$layers), 2)
 })
 
 test_that("stops", {
@@ -48,9 +49,11 @@ test_that("stops", {
   # must have censor to plot
   expect_error(ggsurv(lungNoCensor, plot.cens = TRUE))
 
-
   noCensor <- subset(kidney, status == 1)
-  kidneyNoCensor <- survival::survfit(Surv(time, status) ~ disease, data = noCensor)
+  kidneyNoCensor <- survival::survfit(
+    Surv(time, status) ~ disease,
+    data = noCensor
+  )
 
   # check that the surv.col and lty.est are of the correct length.  should be 4
   expect_error(ggsurv(kidneyNoCensor, surv.col = c("black", "red", "blue")))
@@ -88,7 +91,6 @@ test_that("back.white", {
 test_that("surv.col", {
   ggsurv(sf.lung, surv.col = "red")
 
-
   ggsurv(sf.kid, surv.col = "red")
   ggsurv(sf.kid, surv.col = c("black", "red", "blue", "green"))
 
@@ -101,29 +103,29 @@ test_that("surv.col", {
 test_that("CI", {
   a <- ggsurv(sf.lung, CI = FALSE)
   b <- ggsurv(sf.lung, CI = TRUE)
-  expect_equivalent(length(b$layers) - length(a$layers), 2)
+  expect_equal(length(b$layers) - length(a$layers), 2)
 
   a <- ggsurv(sf.kid, CI = FALSE)
   b <- ggsurv(sf.kid, CI = TRUE)
-  expect_equivalent(length(b$layers) - length(a$layers), 2)
+  expect_equal(length(b$layers) - length(a$layers), 2)
 })
 
 test_that("multiple colors", {
   p <- ggsurv(sf.kid, plot.cens = TRUE)
-  vdiffr::expect_doppelganger("plot-cens-true", p)
+  ggally_expect_doppelganger("plot-cens-true", p)
   expect_warning(
     {
       ggsurv(sf.kid, plot.cens = TRUE, cens.col = c("red", "blue"))
     },
     "Color scales for censored points"
-  ) # nolint
+  )
 
   p <- ggsurv(sf.kid, plot.cens = TRUE, cens.col = "blue")
-  vdiffr::expect_doppelganger("plot-cens-true-blue", p)
+  ggally_expect_doppelganger("plot-cens-true-blue", p)
 
   custom_color <- c("green", "blue", "purple", "orange")
   p <- ggsurv(sf.kid, plot.cens = TRUE, cens.col = custom_color)
-  vdiffr::expect_doppelganger("plot-cens-true-custom", p)
+  ggally_expect_doppelganger("plot-cens-true-custom", p)
 
   expect_warning(
     {
@@ -135,7 +137,7 @@ test_that("multiple colors", {
       )
     },
     "The length of the censored shapes"
-  ) # nolint
+  )
   p <-
     ggsurv(
       sf.kid,
@@ -143,7 +145,7 @@ test_that("multiple colors", {
       cens.col = custom_color,
       cens.shape = c(1, 2, 3, 4)
     )
-  vdiffr::expect_doppelganger("plot-cens-true-custom-shape", p)
+  ggally_expect_doppelganger("plot-cens-true-custom-shape", p)
 })
 
 test_that("cens.size", {
