@@ -1,4 +1,3 @@
-context("ggpairs")
 # This file takes too long
 testthat::skip_on_cran()
 
@@ -16,20 +15,19 @@ test_that("structure", {
   }
 
   expect_obj <- function(x) {
-    expect_is(x$data, "data.frame")
-    expect_is(x$plots, "list")
-    expect_equivalent(length(x$plots), ncol(tips)^2)
+    expect_s3_class(x$data, "data.frame")
+    expect_type(x$plots, "list")
+    expect_equal(length(x$plots), ncol(tips)^2)
     expect_null(x$title)
     expect_null(x$xlab)
     expect_null(x$ylab)
-    expect_is(x$xAxisLabels, "character")
-    expect_is(x$yAxisLabels, "character")
-    expect_is(x$showXAxisPlotLabels, "logical")
-    expect_is(x$showYAxisPlotLabels, "logical")
+    expect_type(x$xAxisLabels, "character")
+    expect_type(x$yAxisLabels, "character")
+    expect_type(x$showXAxisPlotLabels, "logical")
+    expect_type(x$showYAxisPlotLabels, "logical")
     expect_null(x$legend)
-    expect_is(x$byrow, "logical")
+    expect_type(x$byrow, "logical")
     expect_null(x$gg)
-    expect_true("gg" %in% names(x))
   }
 
   expect_obj(ggduo(tips))
@@ -38,11 +36,11 @@ test_that("structure", {
 
 test_that("columns", {
   expect_obj <- function(pm, columnsX, columnsY) {
-    expect_equivalent(length(pm$plots), length(columnsX) * length(columnsY))
-    expect_equivalent(pm$xAxisLabels, columnsX)
-    expect_equivalent(pm$yAxisLabels, columnsY)
-    expect_equivalent(pm$ncol, length(columnsX))
-    expect_equivalent(pm$nrow, length(columnsY))
+    expect_equal(length(pm$plots), length(columnsX) * length(columnsY))
+    expect_equal(pm$xAxisLabels, columnsX)
+    expect_equal(pm$yAxisLabels, columnsY)
+    expect_equal(pm$ncol, length(columnsX))
+    expect_equal(pm$nrow, length(columnsY))
   }
 
   columnsUsed <- c("total_bill", "tip", "sex")
@@ -57,8 +55,8 @@ test_that("columns", {
 
 test_that("column labels", {
   expect_obj <- function(pm, columnLabelsX, columnLabelsY) {
-    expect_equivalent(pm$xAxisLabels, columnLabelsX)
-    expect_equivalent(pm$yAxisLabels, columnLabelsY)
+    expect_equal(pm$xAxisLabels, columnLabelsX)
+    expect_equal(pm$yAxisLabels, columnLabelsY)
   }
 
   columnTitles <- c("A", "B", "C")
@@ -71,7 +69,13 @@ test_that("column labels", {
 
   columnLabelsX <- c("Total Bill %", "Tip 123456", "Sex ( /a asdf)")
   columnLabelsY <- c("Smoker !#@", "Day 678", "1", "NULL")
-  pm <- ggduo(tips, 1:3, 4:7, columnLabelsX = columnLabelsX, columnLabelsY = columnLabelsY)
+  pm <- ggduo(
+    tips,
+    1:3,
+    4:7,
+    columnLabelsX = columnLabelsX,
+    columnLabelsY = columnLabelsY
+  )
   expect_obj(pm, columnLabelsX, columnLabelsY)
 })
 
@@ -124,203 +128,223 @@ test_that("upper/lower/diag = blank", {
 test_that("stops", {
   expect_warning(
     {
-      pm <- ggpairs(tips, axisLabels = "not_a_chosen", lower = facethistBindwidth1)
+      pm <- ggpairs(
+        tips,
+        axisLabels = "not_a_chosen",
+        lower = facethistBindwidth1
+      )
     },
     "'axisLabels' not in "
-  ) # nolint
+  )
   expect_warning(
     {
-      pm <- ggduo(tips, axisLabels = "not_a_chosen", types = facethistBindwidth1Duo)
+      pm <- ggduo(
+        tips,
+        axisLabels = "not_a_chosen",
+        types = facethistBindwidth1Duo
+      )
     },
     "'axisLabels' not in "
-  ) # nolint
+  )
 
-  expect_warning(
+  lifecycle::expect_deprecated(
     {
       pm <- ggpairs(tips, color = "sex")
     },
-    "Extra arguments: "
-  ) # nolint
+  )
 
   expect_warning(
     {
       pm <- ggduo(tips, 2:3, 2:3, types = list(combo = "facetdensity"))
     },
     "Setting:\n\ttypes"
-  ) # nolint
+  )
 
   expect_error(
     {
       ggpairs(tips, columns = c("tip", "day", "not in tips"))
     },
     "Columns in 'columns' not found in data"
-  ) # nolint
+  )
   expect_error(
     {
-      ggduo(tips, columnsX = c("tip", "day", "not in tips"), columnsY = "smoker")
+      ggduo(
+        tips,
+        columnsX = c("tip", "day", "not in tips"),
+        columnsY = "smoker"
+      )
     },
     "Columns in 'columnsX' not found in data"
-  ) # nolint
+  )
   expect_error(
     {
-      ggduo(tips, columnsX = c("tip", "day", "smoker"), columnsY = "not in tips")
+      ggduo(
+        tips,
+        columnsX = c("tip", "day", "smoker"),
+        columnsY = "not in tips"
+      )
     },
     "Columns in 'columnsY' not found in data"
-  ) # nolint
+  )
 
-  expect_warning(
+  lifecycle::expect_deprecated(
     {
       pm <- ggpairs(tips, legends = TRUE)
-    },
-    "'legends' will be deprecated"
-  ) # nolint
+    }
+  )
 
-  expect_error(
+  lifecycle::expect_deprecated(
     {
       ggpairs(tips, params = c(size = 2))
-    },
-    "'params' is a deprecated"
-  ) # nolint
+    }
+  )
 
   expect_error(
     {
       ggpairs(tips, columns = 1:10)
     },
     "Make sure your numeric 'columns' values are less than or equal to"
-  ) # nolint
+  )
   expect_error(
     {
       ggduo(tips, columnsX = 1:10)
     },
     "Make sure your numeric 'columnsX' values are less than or equal to"
-  ) # nolint
+  )
   expect_error(
     {
       ggduo(tips, columnsY = 1:10)
     },
     "Make sure your numeric 'columnsY' values are less than or equal to"
-  ) # nolint
+  )
 
   expect_error(
     {
       ggpairs(tips, columns = -5:5)
     },
     "Make sure your numeric 'columns' values are positive"
-  ) # nolint
+  )
   expect_error(
     {
       ggduo(tips, columnsX = -5:5)
     },
     "Make sure your numeric 'columnsX' values are positive"
-  ) # nolint
+  )
   expect_error(
     {
       ggduo(tips, columnsY = -5:5)
     },
     "Make sure your numeric 'columnsY' values are positive"
-  ) # nolint
+  )
 
   expect_error(
     {
       ggpairs(tips, columns = (2:10) / 2)
     },
     "Make sure your numeric 'columns' values are integers"
-  ) # nolint
+  )
   expect_error(
     {
       ggduo(tips, columnsX = (2:10) / 2)
     },
     "Make sure your numeric 'columnsX' values are integers"
-  ) # nolint
+  )
   expect_error(
     {
       ggduo(tips, columnsY = (2:10) / 2)
     },
     "Make sure your numeric 'columnsY' values are integers"
-  ) # nolint
+  )
 
   expect_error(
     {
       ggpairs(tips, columns = 1:3, columnLabels = c("A", "B", "C", "Extra"))
     },
     "The length of the 'columnLabels' does not match the length of the 'columns'"
-  ) # nolint
+  )
   expect_error(
     {
       ggduo(tips, columnsX = 1:3, columnLabelsX = c("A", "B", "C", "Extra"))
     },
     "The length of the 'columnLabelsX' does not match the length of the 'columnsX'"
-  ) # nolint
+  )
   expect_error(
     {
       ggduo(tips, columnsY = 1:3, columnLabelsY = c("A", "B", "C", "Extra"))
     },
     "The length of the 'columnLabelsY' does not match the length of the 'columnsY'"
-  ) # nolint
+  )
 
   expect_error(
     {
       ggpairs(tips, upper = c("not_a_list"))
     },
     "'upper' is not a list"
-  ) # nolint
+  )
   expect_error(
     {
       ggpairs(tips, diag = c("not_a_list"))
     },
     "'diag' is not a list"
-  ) # nolint
+  )
   expect_error(
     {
       ggpairs(tips, lower = c("not_a_list"))
     },
     "'lower' is not a list"
-  ) # nolint
+  )
   expect_error(
     {
       ggduo(tips, types = c("not_a_list"))
     },
     "'types' is not a list"
-  ) # nolint
+  )
 
   # # couldn't get correct error message
   # #  variables: 'colour' have non standard format: 'total_bill + tip'.
   # expect_error({
   #   ggpairs(tips, mapping = ggplot2::aes(color = total_bill + tip))
-  # }, "variables\\: \"colour\" have non standard format") # nolint
+  # }, "variables\\: \"colour\" have non standard format")
   # expect_error({
   #   ggduo(tips, mapping = ggplot2::aes(color = total_bill + tip))
-  # }, "variables\\: \"colour\" have non standard format") # nolint
+  # }, "variables\\: \"colour\" have non standard format")
 
   errorString <- "'aes_string' is a deprecated element"
   expect_error(
     {
-      ggpairs(tips, upper = list(aes_string = ggplot2::aes(color = day)))
+      ggpairs(tips, upper = list(aes_string = ggplot2::aes(color = .data$day)))
     },
     errorString
-  ) # nolint
+  )
   expect_error(
     {
-      ggpairs(tips, lower = list(aes_string = ggplot2::aes(color = day)))
+      ggpairs(tips, lower = list(aes_string = ggplot2::aes(color = .data$day)))
     },
     errorString
-  ) # nolint
+  )
   expect_error(
     {
-      ggpairs(tips, diag = list(aes_string = ggplot2::aes(color = day)))
+      ggpairs(tips, diag = list(aes_string = ggplot2::aes(color = .data$day)))
     },
     errorString
-  ) # nolint
+  )
   expect_error(
     {
-      ggduo(tips, types = list(aes_string = ggplot2::aes(color = day)))
+      ggduo(tips, types = list(aes_string = ggplot2::aes(color = .data$day)))
     },
     errorString
-  ) # nolint
-
+  )
 
   expect_diag_warn <- function(key, value) {
-    warnString <- str_c("Changing diag\\$", key, " from '", value, "' to '", value, "Diag'")
+    warnString <- str_c(
+      "Changing diag\\$",
+      key,
+      " from '",
+      value,
+      "' to '",
+      value,
+      "Diag'"
+    )
     diagObj <- list()
     diagObj[[key]] <- value
     expect_warning(
@@ -361,8 +385,18 @@ test_that("cardinality", {
 
 test_that("blank types", {
   columnsUsed <- 1:3
-  pmUpper <- ggpairs(tips, columnsUsed, upper = "blank", lower = facethistBindwidth1)
-  pmDiag <- ggpairs(tips, columnsUsed, diag = "blank", lower = facethistBindwidth1)
+  pmUpper <- ggpairs(
+    tips,
+    columnsUsed,
+    upper = "blank",
+    lower = facethistBindwidth1
+  )
+  pmDiag <- ggpairs(
+    tips,
+    columnsUsed,
+    diag = "blank",
+    lower = facethistBindwidth1
+  )
   pmLower <- ggpairs(tips, columnsUsed, lower = "blank")
 
   for (i in columnsUsed) {
@@ -421,12 +455,16 @@ test_that("axisLabels", {
       expect_false(is.null(pm$xAxisLabels))
       expect_false(is.null(pm$yAxisLabels))
     }
-    vdiffr::expect_doppelganger(paste0("axisLabels-", prefix, "-", axisLabel), pm)
+    ggally_expect_doppelganger(
+      paste0("axisLabels-", prefix, "-", axisLabel),
+      pm
+    )
   }
 
   fn <- function(axisLabels) {
     pm <- ggpairs(
-      iris, c(3, 4, 5, 1),
+      iris,
+      c(3, 4, 5, 1),
       upper = "blank",
       lower = facethistBindwidth1,
       axisLabels = axisLabels,
@@ -442,17 +480,20 @@ test_that("axisLabels", {
   plots <- ggpairs(iris, 1:3)$plots
   for (val in c(TRUE, FALSE)) {
     pm <- ggmatrix(
-      plots, 3, 3,
+      plots,
+      3,
+      3,
       showAxisPlotLabels = val
     )
     expect_equal(pm$showXAxisPlotLabels, val)
     expect_equal(pm$showYAxisPlotLabels, val)
   }
 
-
   fn <- function(axisLabels) {
     a <- ggduo(
-      iris, c(4, 5), c(5, 1),
+      iris,
+      c(4, 5),
+      c(5, 1),
       types = facethistBindwidth1Duo,
       axisLabels = axisLabels,
       title = str_c("axisLabels = ", axisLabels)
@@ -468,12 +509,13 @@ test_that("axisLabels", {
 test_that("strips and axis", {
   # axis should line up with left side strips
   pm <- ggpairs(
-    tips, c(3, 1, 4),
+    tips,
+    c(3, 1, 4),
     showStrips = TRUE,
     title = "Axis should line up even if strips are present",
     lower = list(combo = wrap("facethist", binwidth = 1))
   )
-  vdiffr::expect_doppelganger("show-strips", pm)
+  ggally_expect_doppelganger("show-strips", pm)
   # default behavior. tested in other places
   # expect_silent({
   #   pm <- ggpairs(tips, c(3, 1, 4), showStrips = FALSE)
@@ -497,7 +539,8 @@ test_that("dates", {
   class(x) <- c("NOT_data.frame", "data.frame")
 
   a <- ggpairs(
-    x, c(2, 1, 4, 3),
+    x,
+    c(2, 1, 4, 3),
     mapping = ggplot2::aes(color = cat),
     lower = "blank",
     diag = list(continuous = "densityDiag"),
@@ -508,9 +551,9 @@ test_that("dates", {
   expect_true(inherits(p$layers[[2]]$geom, "GeomText"))
   expect_equal(length(p$layers), 2)
 
-
   a <- ggpairs(
-    x, c(2, 1, 4, 3),
+    x,
+    c(2, 1, 4, 3),
     mapping = ggplot2::aes(color = cat),
     lower = "blank",
     diag = list(continuous = "barDiag"),
@@ -534,7 +577,7 @@ test_that("mapping", {
       ggpairs(tips, columns = 1:3, mapping = 1:3)
     },
     "'mapping' should not be numeric"
-  ) # nolint
+  )
 })
 
 test_that("user functions", {
@@ -556,8 +599,18 @@ test_that("user functions", {
       "GeomPoint" %in% class(y$layers[[1]]$geom)
     )
 
-    expect_equal(x$labels, list(x = "total_bill", y = "tip"))
-    expect_equal(x$labels, y$labels)
+    if (packageVersion("ggplot2") > "3.5.2") {
+      x_built <- ggplot2::build_ggplot(x)
+      y_built <- ggplot2::build_ggplot(y)
+      expect_equal(
+        x_built@plot@labels[c("x", "y")],
+        list(x = "total_bill", y = "tip")
+      )
+      expect_equal(x_built@plot@labels, y_built@plot@labels)
+    } else {
+      expect_equal(x$labels, list(x = "total_bill", y = "tip"))
+      expect_equal(x$labels, y$labels)
+    }
   }
   expect_equal_plots(p0, p1)
   expect_equal_plots(p0, p2)
@@ -567,7 +620,7 @@ test_that("NA data", {
   expect_is_na_plot <- function(p) {
     expect_true(identical(as.character(p$data$label), "NA"))
     expect_true(inherits(p$layers[[1]]$geom, "GeomText"))
-    expect_equivalent(length(p$layers), 1)
+    expect_equal(length(p$layers), 1)
   }
   expect_not_na_plot <- function(p) {
     expect_false(identical(as.character(p$data$label), "NA"))
@@ -576,7 +629,12 @@ test_that("NA data", {
     expect_true(is_blank_plot(p))
   }
 
-  dd <- data.frame(x = c(1:5, rep(NA, 5)), y = c(rep(NA, 5), 2:6), z = 1:10, w = NA)
+  dd <- data.frame(
+    x = c(1:5, rep(NA, 5)),
+    y = c(rep(NA, 5), 2:6),
+    z = 1:10,
+    w = NA
+  )
   pm <- ggpairs(dd)
 
   test_pm <- function(pm, na_mat) {
@@ -613,164 +671,246 @@ test_that("strip-top and strip-right", {
   data(tips)
 
   double_strips <- function(data, mapping, ...) {
-    dt <- plyr::count(data, c(mapping_string(mapping$x), mapping_string(mapping$y)))
+    dt <- dplyr::count(
+      data,
+      .data[[mapping_string(mapping$x)]],
+      .data[[mapping_string(mapping$y)]],
+      name = "freq"
+    )
     ggplot(dt, aes(xmin = 0.25, xmax = 0.75, ymin = 1, ymax = freq)) +
       geom_rect() +
-      ggplot2::facet_grid(paste0(mapping_string(mapping$y), " ~ ", mapping_string(mapping$x))) +
+      ggplot2::facet_grid(paste0(
+        mapping_string(mapping$y),
+        " ~ ",
+        mapping_string(mapping$x)
+      )) +
       ggplot2::scale_x_continuous(breaks = 0.5, labels = NULL)
   }
 
   pm <- ggpairs(
-    tips, 3:6,
-    lower = "blank", diag = "blank",
+    tips,
+    3:6,
+    lower = "blank",
+    diag = "blank",
     upper = list(discrete = double_strips),
     progress = FALSE
   )
-  vdiffr::expect_doppelganger("nested-strips-default", pm)
+  ggally_expect_doppelganger("nested-strips-default", pm)
   pm <- ggpairs(
-    tips, 3:6,
-    lower = "blank", diag = "blank",
+    tips,
+    3:6,
+    lower = "blank",
+    diag = "blank",
     upper = list(discrete = double_strips),
     showStrips = TRUE,
     progress = FALSE
   )
-  vdiffr::expect_doppelganger("nested-strips-true", pm)
+  ggally_expect_doppelganger("nested-strips-true", pm)
 })
 
 
-test_that("subtypes", {
-  testthat::skip_on_cran()
-  testthat::skip_if_not_installed("Hmisc")
-
-  # list of the different plot types to check
-  # continuous
-  #    points
-  #    smooth
-  #    smooth_loess
-  #    density
-  #    cor
-  #   blank
-
-  # combo
-  #   box
-  #   dot plot
-  #   facethist
-  #   facetdensity
-  #   denstrip
-  #   blank
-
-  # discrete
-  #   ratio
-  #   facetbar
-  #   blank
-
-  gn <- function(x) {
-    fnName <- attr(x, "name")
-    ifnull(fnName, x)
-  }
-
-  ggpairs_fn1 <- function(title, types, diag, ...) {
-    ggpairs(
-      tips, 1:4,
-      axisLabels = "show",
-      title = paste(
-        "upper = c(cont = ", gn(types$continuous),
-        ", combo = ", gn(types$combo),
-        ", discrete = ", gn(types$discrete),
-        "); diag = c(cont = ", gn(diag$continuous),
-        ", discrete = ", gn(diag$discrete),
-        ")",
-        sep = ""
-      ),
-      upper = types,
-      lower = types,
-      diag = diag,
-      progress = FALSE,
-      ...
-    ) + ggplot2::theme(plot.title = ggplot2::element_text(size = 9))
-  }
-
-  ggpairs_fn2 <- function(...) {
-    ggpairs_fn1(..., mapping = ggplot2::aes(color = day), legend = c(1, 3))
-  }
-
-  ggduo_fn1 <- function(title, types, diag, ...) {
-    types$comboHorizontal <- types$combo
-    types$comboVertical <- types$combo
-    types$combo <- NULL
-    ggduo(
-      tips, 1:3, 1:4,
-      axisLabels = "show",
-      title = paste(
-        "types = c(cont = ", gn(types$continuous),
-        ", combo = ", gn(types$comboHorizontal),
-        ", discrete = ", gn(types$discrete),
-        ")",
-        sep = ""
-      ),
-      types = types,
-      progress = FALSE,
-      ...
-    ) + ggplot2::theme(plot.title = ggplot2::element_text(size = 9))
-  }
-
-  ggduo_fn2 <- function(...) {
-    ggduo_fn1(..., mapping = ggplot2::aes(color = day), legend = 3) +
-      theme(legend.position = "bottom")
-  }
+testthat::skip_on_cran()
+testthat::skip_if_not_installed("Hmisc")
 
 
-  # re ordered the subs so that density can have no binwidth param
-  conSubs <- list(
-    "autopoint",
-    "density", "points", "smooth", "smooth_lm", "smooth_loess", "cor",
-    "blank"
-  )
-  comSubs <- list(
-    "autopoint",
-    "box", "dot", "box_no_facet", "dot_no_facet",
-    wrap("facethist", binwidth = 1),
-    "facetdensity",
-    "facetdensitystrip",
-    # "summarise_by", # Issues with grid printing
-    wrap("denstrip", binwidth = 1),
-    "blank"
-  )
-  disSubs <- list(
-    "autopoint", "colbar", "count",
-    "cross", "crosstable", "facetbar",
-    "ratio", "rowbar",
-    "table",
-    # "trends", # Issues with grid printing
-    "blank"
+# list of the different plot types to check
+# continuous
+#    points
+#    smooth
+#    smooth_loess
+#    density
+#    cor
+#   blank
+
+# combo
+#   box
+#   dot plot
+#   facethist
+#   facetdensity
+#   denstrip
+#   blank
+
+# discrete
+#   ratio
+#   facetbar
+#   blank
+
+gn <- function(x) {
+  fnName <- attr(x, "name")
+  fnName %||% x
+}
+
+ggpairs_fn1 <- function(title, types, diag, ...) {
+  ggpairs(
+    tips,
+    1:4,
+    axisLabels = "show",
+    title = paste(
+      "upper = c(cont = ",
+      gn(types$continuous),
+      ", combo = ",
+      gn(types$combo),
+      ", discrete = ",
+      gn(types$discrete),
+      "); diag = c(cont = ",
+      gn(diag$continuous),
+      ", discrete = ",
+      gn(diag$discrete),
+      ")",
+      sep = ""
+    ),
+    upper = types,
+    lower = types,
+    diag = diag,
+    progress = FALSE,
+    ...
+  ) +
+    ggplot2::theme(plot.title = ggplot2::element_text(size = 9))
+}
+
+ggpairs_fn2 <- function(...) {
+  ggpairs_fn1(
+    ...,
+    mapping = ggplot2::aes(color = !!as.name("day")),
+    legend = c(1, 3)
   )
+}
 
-  conDiagSubs <- c("autopointDiag", "densityDiag", wrap("barDiag", binwidth = 1), "blankDiag")
-  disDiagSubs <- c("autopointDiag", "barDiag", "countDiag", "tableDiag", "blankDiag")
+ggduo_fn1 <- function(title, types, diag, ...) {
+  types$comboHorizontal <- types$combo
+  types$comboVertical <- types$combo
+  types$combo <- NULL
+  ggduo(
+    tips,
+    1:3,
+    1:4,
+    axisLabels = "show",
+    title = paste(
+      "types = c(cont = ",
+      gn(types$continuous),
+      ", combo = ",
+      gn(types$comboHorizontal),
+      ", discrete = ",
+      gn(types$discrete),
+      ")",
+      sep = ""
+    ),
+    types = types,
+    progress = FALSE,
+    ...
+  ) +
+    ggplot2::theme(plot.title = ggplot2::element_text(size = 9))
+}
 
-  # for (fn in list(ggpairs_fn1, ggpairs_fn2, ggduo_fn1, ggduo_fn2)) {
-  for (fn_info in list(
-    list(fn = ggpairs_fn1, title = "ggpairs"),
-    list(fn = ggpairs_fn2, title = "ggpairs_color"),
-    list(fn = ggduo_fn1, title = "ggduo"),
-    list(fn = ggduo_fn2, title = "ggduo_color")
-  )) {
-    fn <- fn_info$fn
-    fn_name <- fn_info$title
-    for (i in 1:max(c(
-      length(conSubs),
-      length(comSubs),
-      length(disSubs),
-      length(conDiagSubs),
-      length(disDiagSubs)
-    ))) {
-      conSub <- if (i <= length(conSubs)) conSubs[[i]] else "blank"
-      comSub <- if (i <= length(comSubs)) comSubs[[i]] else "blank"
-      disSub <- if (i <= length(disSubs)) disSubs[[i]] else "blank"
+ggduo_fn2 <- function(...) {
+  ggduo_fn1(..., mapping = ggplot2::aes(color = .data$day), legend = 3) +
+    theme(legend.position = "bottom")
+}
 
-      diagConSub <- if (i <= length(conDiagSubs)) conDiagSubs[[i]] else "blankDiag"
-      diagDisSub <- if (i <= length(disDiagSubs)) disDiagSubs[[i]] else "blankDiag"
 
+# re ordered the subs so that density can have no binwidth param
+conSubs <- list(
+  "autopoint",
+  "density",
+  "points",
+  "smooth",
+  "smooth_lm",
+  "smooth_loess",
+  "cor",
+  "blank"
+)
+comSubs <- list(
+  "autopoint",
+  "box",
+  "dot",
+  "box_no_facet",
+  "dot_no_facet",
+  wrap("facethist", binwidth = 1),
+  "facetdensity",
+  "facetdensitystrip",
+  # "summarise_by", # Issues with grid printing
+  wrap("denstrip", binwidth = 1),
+  "blank"
+)
+disSubs <- list(
+  "autopoint",
+  "colbar",
+  "count",
+  "cross",
+  "crosstable",
+  "facetbar",
+  "ratio",
+  "rowbar",
+  "table",
+  # "trends", # Issues with grid printing
+  "blank"
+)
+
+conDiagSubs <- c(
+  "autopointDiag",
+  "densityDiag",
+  wrap("barDiag", binwidth = 1),
+  "blankDiag"
+)
+disDiagSubs <- c(
+  "autopointDiag",
+  "barDiag",
+  "countDiag",
+  "tableDiag",
+  "blankDiag"
+)
+
+# for (fn in list(ggpairs_fn1, ggpairs_fn2, ggduo_fn1, ggduo_fn2)) {
+for (fn_info in list(
+  list(fn = ggpairs_fn1, title = "ggpairs"),
+  list(fn = ggpairs_fn2, title = "ggpairs_color"),
+  list(fn = ggduo_fn1, title = "ggduo"),
+  list(fn = ggduo_fn2, title = "ggduo_color")
+)) {
+  fn <- fn_info$fn
+  fn_name <- fn_info$title
+  for (i in 1:max(c(
+    length(conSubs),
+    length(comSubs),
+    length(disSubs),
+    length(conDiagSubs),
+    length(disDiagSubs)
+  ))) {
+    conSub <- if (i <= length(conSubs)) conSubs[[i]] else "blank"
+    comSub <- if (i <= length(comSubs)) comSubs[[i]] else "blank"
+    disSub <- if (i <= length(disSubs)) disSubs[[i]] else "blank"
+
+    diagConSub <- if (i <= length(conDiagSubs)) {
+      conDiagSubs[[i]]
+    } else {
+      "blankDiag"
+    }
+    diagDisSub <- if (i <= length(disDiagSubs)) {
+      disDiagSubs[[i]]
+    } else {
+      "blankDiag"
+    }
+
+    type_name <- function(x) {
+      if (is.function(x)) {
+        sub("ggally_", "", attr(x, "name"))
+      } else {
+        x
+      }
+    }
+    type_names <- vapply(
+      c(conSub, comSub, disSub, diagConSub, diagDisSub),
+      type_name,
+      character(1)
+    )
+    if (all(grepl("blank", type_names))) {
+      # vdiffr can't handle blank plots
+      next
+    }
+    pm_name <- paste0(type_names, collapse = "-")
+    pm_name <- paste0(fn_name, "-", pm_name)
+
+    test_that(paste0("subtypes", "-", pm_name), {
       # print(list(
       #   fn_num = fn_num,
       #   types = list(
@@ -798,49 +938,44 @@ test_that("subtypes", {
         )
       })
 
-      type_name <- function(x) {
-        if (is.function(x)) {
-          sub("ggally_", "", attr(x, "name"))
-        } else {
-          x
-        }
-      }
-      type_names <- vapply(c(conSub, comSub, disSub, diagConSub, diagDisSub), type_name, character(1))
-      if (all(grepl("blank", type_names))) {
-        # vdiffr can't handle blank plots
-        next
-      }
-      pm_name <- paste0(type_names, collapse = "-")
-      pm_name <- paste0(fn_name, "-", pm_name)
-
       tryCatch(
         {
           set.seed(123456) # keep jitter consistent
           suppressWarnings({
             built_pm <- ggmatrix_gtable(pm)
           })
-          vdiffr::expect_doppelganger(pm_name, built_pm)
+          ggally_expect_doppelganger(pm_name, built_pm)
         },
         error = function(e) {
-          message("failed to create doppelganger: ", pm_name)
-          print(e)
-          barret <<- pm
-          expect_silent(print(c("failed to create doppelganger", pm_name)))
+          if (interactive()) {
+            assign("barret", pm, envir = globalenv())
+          }
+          # Rethrow error
+          signalCondition(e)
         }
       )
-    }
+    })
   }
+}
+
+
+test_that("bad types", {
+  skip_on_cran()
 
   expect_error({
-    ggpairs(tips, 1:2, lower = "blank", diag = "blank", upper = list(continuous = "BAD_TYPE"))
+    ggpairs(
+      tips,
+      1:2,
+      lower = "blank",
+      diag = "blank",
+      upper = list(continuous = "BAD_TYPE")
+    )
   })
 })
 
-
 # pm <- ggpairs(tips, upper = "blank")
 # # pm
 
-
 #  # Custom Example
 #  pm <- ggpairs(
 #    tips[, c(1, 3, 4, 2)],
